from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class LegendEntry(Serialisable):
    tagname: str
    idx: Incomplete
    delete: Incomplete
    txPr: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self, idx: int = ..., delete: bool = ..., txPr: Incomplete | None = ..., extLst: Incomplete | None = ...
    ) -> None: ...

class Legend(Serialisable):
    tagname: str
    legendPos: Incomplete
    position: Incomplete
    legendEntry: Incomplete
    layout: Incomplete
    overlay: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    txPr: Incomplete
    textProperties: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        legendPos: str = ...,
        legendEntry=...,
        layout: Incomplete | None = ...,
        overlay: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        txPr: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class PictureLocking(Serialisable):
    tagname: str
    namespace: Incomplete
    noCrop: Incomplete
    noGrp: Incomplete
    noSelect: Incomplete
    noRot: Incomplete
    noChangeAspect: Incomplete
    noMove: Incomplete
    noResize: Incomplete
    noEditPoints: Incomplete
    noAdjustHandles: Incomplete
    noChangeArrowheads: Incomplete
    noChangeShapeType: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        noCrop: Incomplete | None = ...,
        noGrp: Incomplete | None = ...,
        noSelect: Incomplete | None = ...,
        noRot: Incomplete | None = ...,
        noChangeAspect: Incomplete | None = ...,
        noMove: Incomplete | None = ...,
        noResize: Incomplete | None = ...,
        noEditPoints: Incomplete | None = ...,
        noAdjustHandles: Incomplete | None = ...,
        noChangeArrowheads: Incomplete | None = ...,
        noChangeShapeType: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class NonVisualPictureProperties(Serialisable):
    tagname: str
    preferRelativeResize: Incomplete
    picLocks: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self, preferRelativeResize: Incomplete | None = ..., picLocks: Incomplete | None = ..., extLst: Incomplete | None = ...
    ) -> None: ...

class PictureNonVisual(Serialisable):
    tagname: str
    cNvPr: Incomplete
    cNvPicPr: Incomplete
    __elements__: Incomplete
    def __init__(self, cNvPr: Incomplete | None = ..., cNvPicPr: Incomplete | None = ...) -> None: ...

class PictureFrame(Serialisable):
    tagname: str
    macro: Incomplete
    fPublished: Incomplete
    nvPicPr: Incomplete
    blipFill: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    style: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        macro: Incomplete | None = ...,
        fPublished: Incomplete | None = ...,
        nvPicPr: Incomplete | None = ...,
        blipFill: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        style: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete
from abc import abstractmethod

from openpyxl.descriptors.serialisable import Serialisable

from ._chart import ChartBase

class _PieChartBase(ChartBase):
    varyColors: Incomplete
    ser: Incomplete
    dLbls: Incomplete
    dataLabels: Incomplete
    __elements__: Incomplete
    def __init__(self, varyColors: bool = ..., ser=..., dLbls: Incomplete | None = ...) -> None: ...
    @property
    @abstractmethod
    def tagname(self) -> str: ...

class PieChart(_PieChartBase):
    tagname: str
    varyColors: Incomplete
    ser: Incomplete
    dLbls: Incomplete
    firstSliceAng: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(self, firstSliceAng: int = ..., extLst: Incomplete | None = ..., **kw) -> None: ...

class PieChart3D(_PieChartBase):
    tagname: str
    varyColors: Incomplete
    ser: Incomplete
    dLbls: Incomplete
    extLst: Incomplete
    __elements__: Incomplete

class DoughnutChart(_PieChartBase):
    tagname: str
    varyColors: Incomplete
    ser: Incomplete
    dLbls: Incomplete
    firstSliceAng: Incomplete
    holeSize: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(self, firstSliceAng: int = ..., holeSize: int = ..., extLst: Incomplete | None = ..., **kw) -> None: ...

class CustomSplit(Serialisable):
    tagname: str
    secondPiePt: Incomplete
    __elements__: Incomplete
    def __init__(self, secondPiePt=...) -> None: ...

class ProjectedPieChart(_PieChartBase):
    tagname: str
    varyColors: Incomplete
    ser: Incomplete
    dLbls: Incomplete
    ofPieType: Incomplete
    type: Incomplete
    gapWidth: Incomplete
    splitType: Incomplete
    splitPos: Incomplete
    custSplit: Incomplete
    secondPieSize: Incomplete
    serLines: Incomplete
    join_lines: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        ofPieType: str = ...,
        gapWidth: Incomplete | None = ...,
        splitType: str = ...,
        splitPos: Incomplete | None = ...,
        custSplit: Incomplete | None = ...,
        secondPieSize: int = ...,
        serLines: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
        **kw,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class WorkbookProperties(Serialisable):
    tagname: str
    date1904: Incomplete
    dateCompatibility: Incomplete
    showObjects: Incomplete
    showBorderUnselectedTables: Incomplete
    filterPrivacy: Incomplete
    promptedSolutions: Incomplete
    showInkAnnotation: Incomplete
    backupFile: Incomplete
    saveExternalLinkValues: Incomplete
    updateLinks: Incomplete
    codeName: Incomplete
    hidePivotFieldList: Incomplete
    showPivotChartFilter: Incomplete
    allowRefreshQuery: Incomplete
    publishItems: Incomplete
    checkCompatibility: Incomplete
    autoCompressPictures: Incomplete
    refreshAllConnections: Incomplete
    defaultThemeVersion: Incomplete
    def __init__(
        self,
        date1904: Incomplete | None = ...,
        dateCompatibility: Incomplete | None = ...,
        showObjects: Incomplete | None = ...,
        showBorderUnselectedTables: Incomplete | None = ...,
        filterPrivacy: Incomplete | None = ...,
        promptedSolutions: Incomplete | None = ...,
        showInkAnnotation: Incomplete | None = ...,
        backupFile: Incomplete | None = ...,
        saveExternalLinkValues: Incomplete | None = ...,
        updateLinks: Incomplete | None = ...,
        codeName: Incomplete | None = ...,
        hidePivotFieldList: Incomplete | None = ...,
        showPivotChartFilter: Incomplete | None = ...,
        allowRefreshQuery: Incomplete | None = ...,
        publishItems: Incomplete | None = ...,
        checkCompatibility: Incomplete | None = ...,
        autoCompressPictures: Incomplete | None = ...,
        refreshAllConnections: Incomplete | None = ...,
        defaultThemeVersion: Incomplete | None = ...,
    ) -> None: ...

class CalcProperties(Serialisable):
    tagname: str
    calcId: Incomplete
    calcMode: Incomplete
    fullCalcOnLoad: Incomplete
    refMode: Incomplete
    iterate: Incomplete
    iterateCount: Incomplete
    iterateDelta: Incomplete
    fullPrecision: Incomplete
    calcCompleted: Incomplete
    calcOnSave: Incomplete
    concurrentCalc: Incomplete
    concurrentManualCount: Incomplete
    forceFullCalc: Incomplete
    def __init__(
        self,
        calcId: int = ...,
        calcMode: Incomplete | None = ...,
        fullCalcOnLoad: bool = ...,
        refMode: Incomplete | None = ...,
        iterate: Incomplete | None = ...,
        iterateCount: Incomplete | None = ...,
        iterateDelta: Incomplete | None = ...,
        fullPrecision: Incomplete | None = ...,
        calcCompleted: Incomplete | None = ...,
        calcOnSave: Incomplete | None = ...,
        concurrentCalc: Incomplete | None = ...,
        concurrentManualCount: Incomplete | None = ...,
        forceFullCalc: Incomplete | None = ...,
    ) -> None: ...

class FileVersion(Serialisable):
    tagname: str
    appName: Incomplete
    lastEdited: Incomplete
    lowestEdited: Incomplete
    rupBuild: Incomplete
    codeName: Incomplete
    def __init__(
        self,
        appName: Incomplete | None = ...,
        lastEdited: Incomplete | None = ...,
        lowestEdited: Incomplete | None = ...,
        rupBuild: Incomplete | None = ...,
        codeName: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class CellWatch(Serialisable):
    tagname: str
    r: Incomplete
    def __init__(self, r: Incomplete | None = ...) -> None: ...

class CellWatches(Serialisable):
    tagname: str
    cellWatch: Incomplete
    __elements__: Incomplete
    def __init__(self, cellWatch=...) -> None: ...



from _typeshed import Incomplete
from collections.abc import Generator

from openpyxl.descriptors import Strict

class DummyWorksheet:
    title: Incomplete
    def __init__(self, title) -> None: ...

class Reference(Strict):
    min_row: Incomplete
    max_row: Incomplete
    min_col: Incomplete
    max_col: Incomplete
    range_string: Incomplete
    worksheet: Incomplete
    def __init__(
        self,
        worksheet: Incomplete | None = ...,
        min_col: Incomplete | None = ...,
        min_row: Incomplete | None = ...,
        max_col: Incomplete | None = ...,
        max_row: Incomplete | None = ...,
        range_string: Incomplete | None = ...,
    ) -> None: ...
    def __len__(self) -> int: ...
    def __eq__(self, other): ...
    @property
    def rows(self) -> Generator[Incomplete, None, None]: ...
    @property
    def cols(self) -> Generator[Incomplete, None, None]: ...
    def pop(self): ...
    @property
    def sheetname(self): ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class NamedStyle(Serialisable):  # type: ignore[misc]
    font: Incomplete
    fill: Incomplete
    border: Incomplete
    alignment: Incomplete
    number_format: Incomplete
    protection: Incomplete
    builtinId: Incomplete
    hidden: Incomplete
    # Overwritten by property below
    # xfId: Integer
    name: Incomplete
    def __init__(
        self,
        name: str = ...,
        font=...,
        fill=...,
        border=...,
        alignment=...,
        number_format: Incomplete | None = ...,
        protection=...,
        builtinId: Incomplete | None = ...,
        hidden: bool = ...,
        xfId: Incomplete | None = ...,
    ) -> None: ...
    def __setattr__(self, attr: str, value) -> None: ...
    def __iter__(self): ...
    @property
    def xfId(self): ...
    def bind(self, wb) -> None: ...
    def as_tuple(self): ...
    def as_xf(self): ...
    def as_name(self): ...

class NamedStyleList(list[Incomplete]):
    @property
    def names(self): ...
    def __getitem__(self, key): ...
    def append(self, style) -> None: ...

class _NamedCellStyle(Serialisable):
    tagname: str
    name: Incomplete
    xfId: Incomplete
    builtinId: Incomplete
    iLevel: Incomplete
    hidden: Incomplete
    customBuiltin: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        name: Incomplete | None = ...,
        xfId: Incomplete | None = ...,
        builtinId: Incomplete | None = ...,
        iLevel: Incomplete | None = ...,
        hidden: Incomplete | None = ...,
        customBuiltin: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class _NamedCellStyleList(Serialisable):
    tagname: str
    # Overwritten by property below
    # count: Integer
    cellStyle: Incomplete
    __attrs__: Incomplete
    def __init__(self, count: Incomplete | None = ..., cellStyle=...) -> None: ...
    @property
    def count(self): ...
    @property
    def names(self): ...



from _typeshed import Incomplete

class TokenizerError(Exception): ...

class Tokenizer:
    SN_RE: Incomplete
    WSPACE_RE: Incomplete
    STRING_REGEXES: Incomplete
    ERROR_CODES: Incomplete
    TOKEN_ENDERS: str
    formula: Incomplete
    items: Incomplete
    token_stack: Incomplete
    offset: int
    token: Incomplete
    def __init__(self, formula) -> None: ...
    def check_scientific_notation(self): ...
    def assert_empty_token(self, can_follow=...) -> None: ...
    def save_token(self) -> None: ...
    def render(self): ...

class Token:
    LITERAL: str
    OPERAND: str
    FUNC: str
    ARRAY: str
    PAREN: str
    SEP: str
    OP_PRE: str
    OP_IN: str
    OP_POST: str
    WSPACE: str
    value: Incomplete
    type: Incomplete
    subtype: Incomplete
    def __init__(self, value, type_, subtype: str = ...) -> None: ...
    TEXT: str
    NUMBER: str
    LOGICAL: str
    ERROR: str
    RANGE: str
    @classmethod
    def make_operand(cls, value): ...
    OPEN: str
    CLOSE: str
    @classmethod
    def make_subexp(cls, value, func: bool = ...): ...
    def get_closer(self): ...
    ARG: str
    ROW: str
    @classmethod
    def make_separator(cls, value): ...



from _typeshed import Incomplete

from openpyxl.descriptors import Strict
from openpyxl.descriptors.serialisable import Serialisable

FONT_PATTERN: str
COLOR_PATTERN: str
SIZE_REGEX: str
FORMAT_REGEX: Incomplete

class _HeaderFooterPart(Strict):
    text: Incomplete
    font: Incomplete
    size: Incomplete
    RGB: str
    color: Incomplete
    def __init__(
        self,
        text: Incomplete | None = ...,
        font: Incomplete | None = ...,
        size: Incomplete | None = ...,
        color: Incomplete | None = ...,
    ) -> None: ...
    def __bool__(self) -> bool: ...
    @classmethod
    def from_str(cls, text): ...

class HeaderFooterItem(Strict):
    left: Incomplete
    center: Incomplete
    centre: Incomplete
    right: Incomplete
    def __init__(
        self, left: Incomplete | None = ..., right: Incomplete | None = ..., center: Incomplete | None = ...
    ) -> None: ...
    def __bool__(self) -> bool: ...
    def to_tree(self, tagname): ...
    @classmethod
    def from_tree(cls, node): ...

class HeaderFooter(Serialisable):
    tagname: str
    differentOddEven: Incomplete
    differentFirst: Incomplete
    scaleWithDoc: Incomplete
    alignWithMargins: Incomplete
    oddHeader: Incomplete
    oddFooter: Incomplete
    evenHeader: Incomplete
    evenFooter: Incomplete
    firstHeader: Incomplete
    firstFooter: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        differentOddEven: Incomplete | None = ...,
        differentFirst: Incomplete | None = ...,
        scaleWithDoc: Incomplete | None = ...,
        alignWithMargins: Incomplete | None = ...,
        oddHeader: Incomplete | None = ...,
        oddFooter: Incomplete | None = ...,
        evenHeader: Incomplete | None = ...,
        evenFooter: Incomplete | None = ...,
        firstHeader: Incomplete | None = ...,
        firstFooter: Incomplete | None = ...,
    ) -> None: ...
    def __bool__(self) -> bool: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class Extension(Serialisable):
    tagname: str
    uri: Incomplete
    def __init__(self, uri: Incomplete | None = ...) -> None: ...

class ExtensionList(Serialisable):
    tagname: str
    ext: Incomplete
    __elements__: Incomplete
    def __init__(self, ext=...) -> None: ...

class IgnoredError(Serialisable):
    tagname: str
    sqref: Incomplete
    evalError: Incomplete
    twoDigitTextYear: Incomplete
    numberStoredAsText: Incomplete
    formula: Incomplete
    formulaRange: Incomplete
    unlockedFormula: Incomplete
    emptyCellReference: Incomplete
    listDataValidation: Incomplete
    calculatedColumn: Incomplete
    def __init__(
        self,
        sqref: Incomplete | None = ...,
        evalError: bool = ...,
        twoDigitTextYear: bool = ...,
        numberStoredAsText: bool = ...,
        formula: bool = ...,
        formulaRange: bool = ...,
        unlockedFormula: bool = ...,
        emptyCellReference: bool = ...,
        listDataValidation: bool = ...,
        calculatedColumn: bool = ...,
    ) -> None: ...

class IgnoredErrors(Serialisable):
    tagname: str
    ignoredError: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(self, ignoredError=..., extLst: Incomplete | None = ...) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors import Sequence
from openpyxl.descriptors.serialisable import Serialisable

FILL_NONE: str
FILL_SOLID: str
FILL_PATTERN_DARKDOWN: str
FILL_PATTERN_DARKGRAY: str
FILL_PATTERN_DARKGRID: str
FILL_PATTERN_DARKHORIZONTAL: str
FILL_PATTERN_DARKTRELLIS: str
FILL_PATTERN_DARKUP: str
FILL_PATTERN_DARKVERTICAL: str
FILL_PATTERN_GRAY0625: str
FILL_PATTERN_GRAY125: str
FILL_PATTERN_LIGHTDOWN: str
FILL_PATTERN_LIGHTGRAY: str
FILL_PATTERN_LIGHTGRID: str
FILL_PATTERN_LIGHTHORIZONTAL: str
FILL_PATTERN_LIGHTTRELLIS: str
FILL_PATTERN_LIGHTUP: str
FILL_PATTERN_LIGHTVERTICAL: str
FILL_PATTERN_MEDIUMGRAY: str
fills: Incomplete

class Fill(Serialisable):
    tagname: str
    @classmethod
    def from_tree(cls, el): ...

class PatternFill(Fill):
    tagname: str
    __elements__: Incomplete
    patternType: Incomplete
    fill_type: Incomplete
    fgColor: Incomplete
    start_color: Incomplete
    bgColor: Incomplete
    end_color: Incomplete
    def __init__(
        self,
        patternType: Incomplete | None = ...,
        fgColor=...,
        bgColor=...,
        fill_type: Incomplete | None = ...,
        start_color: Incomplete | None = ...,
        end_color: Incomplete | None = ...,
    ) -> None: ...
    def to_tree(self, tagname: Incomplete | None = ..., idx: Incomplete | None = ...): ...  # type: ignore[override]

DEFAULT_EMPTY_FILL: Incomplete
DEFAULT_GRAY_FILL: Incomplete

class Stop(Serialisable):
    tagname: str
    position: Incomplete
    color: Incomplete
    def __init__(self, color, position) -> None: ...

class StopList(Sequence):
    expected_type: Incomplete
    def __set__(self, obj, values) -> None: ...

class GradientFill(Fill):
    tagname: str
    type: Incomplete
    fill_type: Incomplete
    degree: Incomplete
    left: Incomplete
    right: Incomplete
    top: Incomplete
    bottom: Incomplete
    stop: Incomplete
    def __init__(
        self, type: str = ..., degree: int = ..., left: int = ..., right: int = ..., top: int = ..., bottom: int = ..., stop=...
    ) -> None: ...
    def __iter__(self): ...
    def to_tree(self, tagname: Incomplete | None = ..., namespace: Incomplete | None = ..., idx: Incomplete | None = ...): ...  # type: ignore[override]



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class SortCondition(Serialisable):
    tagname: str
    descending: Incomplete
    sortBy: Incomplete
    ref: Incomplete
    customList: Incomplete
    dxfId: Incomplete
    iconSet: Incomplete
    iconId: Incomplete
    def __init__(
        self,
        ref: Incomplete | None = ...,
        descending: Incomplete | None = ...,
        sortBy: Incomplete | None = ...,
        customList: Incomplete | None = ...,
        dxfId: Incomplete | None = ...,
        iconSet: Incomplete | None = ...,
        iconId: Incomplete | None = ...,
    ) -> None: ...

class SortState(Serialisable):
    tagname: str
    columnSort: Incomplete
    caseSensitive: Incomplete
    sortMethod: Incomplete
    ref: Incomplete
    sortCondition: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        columnSort: Incomplete | None = ...,
        caseSensitive: Incomplete | None = ...,
        sortMethod: Incomplete | None = ...,
        ref: Incomplete | None = ...,
        sortCondition=...,
        extLst: Incomplete | None = ...,
    ) -> None: ...
    def __bool__(self) -> bool: ...

class IconFilter(Serialisable):
    tagname: str
    iconSet: Incomplete
    iconId: Incomplete
    def __init__(self, iconSet: Incomplete | None = ..., iconId: Incomplete | None = ...) -> None: ...

class ColorFilter(Serialisable):
    tagname: str
    dxfId: Incomplete
    cellColor: Incomplete
    def __init__(self, dxfId: Incomplete | None = ..., cellColor: Incomplete | None = ...) -> None: ...

class DynamicFilter(Serialisable):
    tagname: str
    type: Incomplete
    val: Incomplete
    valIso: Incomplete
    maxVal: Incomplete
    maxValIso: Incomplete
    def __init__(
        self,
        type: Incomplete | None = ...,
        val: Incomplete | None = ...,
        valIso: Incomplete | None = ...,
        maxVal: Incomplete | None = ...,
        maxValIso: Incomplete | None = ...,
    ) -> None: ...

class CustomFilter(Serialisable):
    tagname: str
    operator: Incomplete
    val: Incomplete
    def __init__(self, operator: Incomplete | None = ..., val: Incomplete | None = ...) -> None: ...

class CustomFilters(Serialisable):
    tagname: str
    customFilter: Incomplete
    __elements__: Incomplete
    def __init__(self, _and: Incomplete | None = ..., customFilter=...) -> None: ...

class Top10(Serialisable):
    tagname: str
    top: Incomplete
    percent: Incomplete
    val: Incomplete
    filterVal: Incomplete
    def __init__(
        self,
        top: Incomplete | None = ...,
        percent: Incomplete | None = ...,
        val: Incomplete | None = ...,
        filterVal: Incomplete | None = ...,
    ) -> None: ...

class DateGroupItem(Serialisable):
    tagname: str
    year: Incomplete
    month: Incomplete
    day: Incomplete
    hour: Incomplete
    minute: Incomplete
    second: Incomplete
    dateTimeGrouping: Incomplete
    def __init__(
        self,
        year: Incomplete | None = ...,
        month: Incomplete | None = ...,
        day: Incomplete | None = ...,
        hour: Incomplete | None = ...,
        minute: Incomplete | None = ...,
        second: Incomplete | None = ...,
        dateTimeGrouping: Incomplete | None = ...,
    ) -> None: ...

class Filters(Serialisable):
    tagname: str
    blank: Incomplete
    calendarType: Incomplete
    filter: Incomplete
    dateGroupItem: Incomplete
    __elements__: Incomplete
    def __init__(
        self, blank: Incomplete | None = ..., calendarType: Incomplete | None = ..., filter=..., dateGroupItem=...
    ) -> None: ...

class FilterColumn(Serialisable):
    tagname: str
    colId: Incomplete
    col_id: Incomplete
    hiddenButton: Incomplete
    showButton: Incomplete
    filters: Incomplete
    top10: Incomplete
    customFilters: Incomplete
    dynamicFilter: Incomplete
    colorFilter: Incomplete
    iconFilter: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        colId: Incomplete | None = ...,
        hiddenButton: Incomplete | None = ...,
        showButton: Incomplete | None = ...,
        filters: Incomplete | None = ...,
        top10: Incomplete | None = ...,
        customFilters: Incomplete | None = ...,
        dynamicFilter: Incomplete | None = ...,
        colorFilter: Incomplete | None = ...,
        iconFilter: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
        blank: Incomplete | None = ...,
        vals: Incomplete | None = ...,
    ) -> None: ...

class AutoFilter(Serialisable):
    tagname: str
    ref: Incomplete
    filterColumn: Incomplete
    sortState: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self, ref: Incomplete | None = ..., filterColumn=..., sortState: Incomplete | None = ..., extLst: Incomplete | None = ...
    ) -> None: ...
    def __bool__(self) -> bool: ...
    def add_filter_column(self, col_id, vals, blank: bool = ...) -> None: ...
    def add_sort_condition(self, ref, descending: bool = ...) -> None: ...



from _typeshed import Incomplete
from abc import abstractmethod

from openpyxl.descriptors.serialisable import Serialisable

class ChartLines(Serialisable):
    tagname: str
    spPr: Incomplete
    graphicalProperties: Incomplete
    def __init__(self, spPr: Incomplete | None = ...) -> None: ...

class Scaling(Serialisable):
    tagname: str
    logBase: Incomplete
    orientation: Incomplete
    max: Incomplete
    min: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        logBase: Incomplete | None = ...,
        orientation: str = ...,
        max: Incomplete | None = ...,
        min: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class _BaseAxis(Serialisable):
    axId: Incomplete
    scaling: Incomplete
    delete: Incomplete
    axPos: Incomplete
    majorGridlines: Incomplete
    minorGridlines: Incomplete
    title: Incomplete
    numFmt: Incomplete
    number_format: Incomplete
    majorTickMark: Incomplete
    minorTickMark: Incomplete
    tickLblPos: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    txPr: Incomplete
    textProperties: Incomplete
    crossAx: Incomplete
    crosses: Incomplete
    crossesAt: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        axId: Incomplete | None = ...,
        scaling: Incomplete | None = ...,
        delete: Incomplete | None = ...,
        axPos: str = ...,
        majorGridlines: Incomplete | None = ...,
        minorGridlines: Incomplete | None = ...,
        title: Incomplete | None = ...,
        numFmt: Incomplete | None = ...,
        majorTickMark: Incomplete | None = ...,
        minorTickMark: Incomplete | None = ...,
        tickLblPos: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        txPr: Incomplete | None = ...,
        crossAx: Incomplete | None = ...,
        crosses: Incomplete | None = ...,
        crossesAt: Incomplete | None = ...,
    ) -> None: ...
    @property
    @abstractmethod
    def tagname(self) -> str: ...

class DisplayUnitsLabel(Serialisable):
    tagname: str
    layout: Incomplete
    tx: Incomplete
    text: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    txPr: Incomplete
    textPropertes: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        layout: Incomplete | None = ...,
        tx: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        txPr: Incomplete | None = ...,
    ) -> None: ...

class DisplayUnitsLabelList(Serialisable):
    tagname: str
    custUnit: Incomplete
    builtInUnit: Incomplete
    dispUnitsLbl: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        custUnit: Incomplete | None = ...,
        builtInUnit: Incomplete | None = ...,
        dispUnitsLbl: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class NumericAxis(_BaseAxis):
    tagname: str
    axId: Incomplete
    scaling: Incomplete
    delete: Incomplete
    axPos: Incomplete
    majorGridlines: Incomplete
    minorGridlines: Incomplete
    title: Incomplete
    numFmt: Incomplete
    majorTickMark: Incomplete
    minorTickMark: Incomplete
    tickLblPos: Incomplete
    spPr: Incomplete
    txPr: Incomplete
    crossAx: Incomplete
    crosses: Incomplete
    crossesAt: Incomplete
    crossBetween: Incomplete
    majorUnit: Incomplete
    minorUnit: Incomplete
    dispUnits: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        crossBetween: Incomplete | None = ...,
        majorUnit: Incomplete | None = ...,
        minorUnit: Incomplete | None = ...,
        dispUnits: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
        **kw,
    ) -> None: ...
    @classmethod
    def from_tree(cls, node): ...

class TextAxis(_BaseAxis):
    tagname: str
    axId: Incomplete
    scaling: Incomplete
    delete: Incomplete
    axPos: Incomplete
    majorGridlines: Incomplete
    minorGridlines: Incomplete
    title: Incomplete
    numFmt: Incomplete
    majorTickMark: Incomplete
    minorTickMark: Incomplete
    tickLblPos: Incomplete
    spPr: Incomplete
    txPr: Incomplete
    crossAx: Incomplete
    crosses: Incomplete
    crossesAt: Incomplete
    auto: Incomplete
    lblAlgn: Incomplete
    lblOffset: Incomplete
    tickLblSkip: Incomplete
    tickMarkSkip: Incomplete
    noMultiLvlLbl: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        auto: Incomplete | None = ...,
        lblAlgn: Incomplete | None = ...,
        lblOffset: int = ...,
        tickLblSkip: Incomplete | None = ...,
        tickMarkSkip: Incomplete | None = ...,
        noMultiLvlLbl: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
        **kw,
    ) -> None: ...

class DateAxis(TextAxis):
    tagname: str
    axId: Incomplete
    scaling: Incomplete
    delete: Incomplete
    axPos: Incomplete
    majorGridlines: Incomplete
    minorGridlines: Incomplete
    title: Incomplete
    numFmt: Incomplete
    majorTickMark: Incomplete
    minorTickMark: Incomplete
    tickLblPos: Incomplete
    spPr: Incomplete
    txPr: Incomplete
    crossAx: Incomplete
    crosses: Incomplete
    crossesAt: Incomplete
    auto: Incomplete
    lblOffset: Incomplete
    baseTimeUnit: Incomplete
    majorUnit: Incomplete
    majorTimeUnit: Incomplete
    minorUnit: Incomplete
    minorTimeUnit: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        auto: Incomplete | None = ...,
        lblOffset: Incomplete | None = ...,
        baseTimeUnit: Incomplete | None = ...,
        majorUnit: Incomplete | None = ...,
        majorTimeUnit: Incomplete | None = ...,
        minorUnit: Incomplete | None = ...,
        minorTimeUnit: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
        **kw,
    ) -> None: ...

class SeriesAxis(_BaseAxis):
    tagname: str
    axId: Incomplete
    scaling: Incomplete
    delete: Incomplete
    axPos: Incomplete
    majorGridlines: Incomplete
    minorGridlines: Incomplete
    title: Incomplete
    numFmt: Incomplete
    majorTickMark: Incomplete
    minorTickMark: Incomplete
    tickLblPos: Incomplete
    spPr: Incomplete
    txPr: Incomplete
    crossAx: Incomplete
    crosses: Incomplete
    crossesAt: Incomplete
    tickLblSkip: Incomplete
    tickMarkSkip: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self, tickLblSkip: Incomplete | None = ..., tickMarkSkip: Incomplete | None = ..., extLst: Incomplete | None = ..., **kw
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class PrintPageSetup(Serialisable):
    tagname: str
    orientation: Incomplete
    paperSize: Incomplete
    scale: Incomplete
    fitToHeight: Incomplete
    fitToWidth: Incomplete
    firstPageNumber: Incomplete
    useFirstPageNumber: Incomplete
    paperHeight: Incomplete
    paperWidth: Incomplete
    pageOrder: Incomplete
    usePrinterDefaults: Incomplete
    blackAndWhite: Incomplete
    draft: Incomplete
    cellComments: Incomplete
    errors: Incomplete
    horizontalDpi: Incomplete
    verticalDpi: Incomplete
    copies: Incomplete
    id: Incomplete
    def __init__(
        self,
        worksheet: Incomplete | None = ...,
        orientation: Incomplete | None = ...,
        paperSize: Incomplete | None = ...,
        scale: Incomplete | None = ...,
        fitToHeight: Incomplete | None = ...,
        fitToWidth: Incomplete | None = ...,
        firstPageNumber: Incomplete | None = ...,
        useFirstPageNumber: Incomplete | None = ...,
        paperHeight: Incomplete | None = ...,
        paperWidth: Incomplete | None = ...,
        pageOrder: Incomplete | None = ...,
        usePrinterDefaults: Incomplete | None = ...,
        blackAndWhite: Incomplete | None = ...,
        draft: Incomplete | None = ...,
        cellComments: Incomplete | None = ...,
        errors: Incomplete | None = ...,
        horizontalDpi: Incomplete | None = ...,
        verticalDpi: Incomplete | None = ...,
        copies: Incomplete | None = ...,
        id: Incomplete | None = ...,
    ) -> None: ...
    def __bool__(self) -> bool: ...
    @property
    def sheet_properties(self): ...
    @property
    def fitToPage(self): ...
    @fitToPage.setter
    def fitToPage(self, value) -> None: ...
    @property
    def autoPageBreaks(self): ...
    @autoPageBreaks.setter
    def autoPageBreaks(self, value) -> None: ...
    @classmethod
    def from_tree(cls, node): ...

class PrintOptions(Serialisable):
    tagname: str
    horizontalCentered: Incomplete
    verticalCentered: Incomplete
    headings: Incomplete
    gridLines: Incomplete
    gridLinesSet: Incomplete
    def __init__(
        self,
        horizontalCentered: Incomplete | None = ...,
        verticalCentered: Incomplete | None = ...,
        headings: Incomplete | None = ...,
        gridLines: Incomplete | None = ...,
        gridLinesSet: Incomplete | None = ...,
    ) -> None: ...
    def __bool__(self) -> bool: ...

class PageMargins(Serialisable):
    tagname: str
    left: Incomplete
    right: Incomplete
    top: Incomplete
    bottom: Incomplete
    header: Incomplete
    footer: Incomplete
    def __init__(
        self, left: float = ..., right: float = ..., top: int = ..., bottom: int = ..., header: float = ..., footer: float = ...
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class ControlProperty(Serialisable):
    tagname: str
    anchor: Incomplete
    locked: Incomplete
    defaultSize: Incomplete
    disabled: Incomplete
    recalcAlways: Incomplete
    uiObject: Incomplete
    autoFill: Incomplete
    autoLine: Incomplete
    autoPict: Incomplete
    macro: Incomplete
    altText: Incomplete
    linkedCell: Incomplete
    listFillRange: Incomplete
    cf: Incomplete
    id: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        anchor: Incomplete | None = ...,
        locked: bool = ...,
        defaultSize: bool = ...,
        _print: bool = ...,
        disabled: bool = ...,
        recalcAlways: bool = ...,
        uiObject: bool = ...,
        autoFill: bool = ...,
        autoLine: bool = ...,
        autoPict: bool = ...,
        macro: Incomplete | None = ...,
        altText: Incomplete | None = ...,
        linkedCell: Incomplete | None = ...,
        listFillRange: Incomplete | None = ...,
        cf: str = ...,
        id: Incomplete | None = ...,
    ) -> None: ...

class Control(Serialisable):
    tagname: str
    controlPr: Incomplete
    shapeId: Incomplete
    name: Incomplete
    __elements__: Incomplete
    def __init__(
        self, controlPr: Incomplete | None = ..., shapeId: Incomplete | None = ..., name: Incomplete | None = ...
    ) -> None: ...

class Controls(Serialisable):
    tagname: str
    control: Incomplete
    __elements__: Incomplete
    def __init__(self, control=...) -> None: ...



from _typeshed import Incomplete
from collections.abc import Generator

ALL_TEMP_FILES: Incomplete

def create_temporary_file(suffix: str = ...): ...

class WorksheetWriter:
    ws: Incomplete
    out: Incomplete
    xf: Incomplete
    def __init__(self, ws, out: Incomplete | None = ...) -> None: ...
    def write_properties(self) -> None: ...
    def write_dimensions(self) -> None: ...
    def write_format(self) -> None: ...
    def write_views(self) -> None: ...
    def write_cols(self) -> None: ...
    def write_top(self) -> None: ...
    def rows(self): ...
    def write_rows(self) -> None: ...
    def write_row(self, xf, row, row_idx) -> None: ...
    def write_protection(self) -> None: ...
    def write_scenarios(self) -> None: ...
    def write_filter(self) -> None: ...
    def write_sort(self) -> None: ...
    def write_merged_cells(self) -> None: ...
    def write_formatting(self) -> None: ...
    def write_validations(self) -> None: ...
    def write_hyperlinks(self) -> None: ...
    def write_print(self) -> None: ...
    def write_margins(self) -> None: ...
    def write_page(self) -> None: ...
    def write_header(self) -> None: ...
    def write_breaks(self) -> None: ...
    def write_drawings(self) -> None: ...
    def write_legacy(self) -> None: ...
    def write_tables(self) -> None: ...
    def get_stream(self) -> Generator[Incomplete, Incomplete, None]: ...
    def write_tail(self) -> None: ...
    def write(self) -> None: ...
    def close(self) -> None: ...
    def read(self): ...
    def cleanup(self) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors import Typed
from openpyxl.descriptors.serialisable import Serialisable

PRESET_COLORS: Incomplete
SCHEME_COLORS: Incomplete

class Transform(Serialisable): ...

class SystemColor(Serialisable):
    tagname: str
    namespace: Incomplete
    tint: Incomplete
    shade: Incomplete
    comp: Incomplete
    inv: Incomplete
    gray: Incomplete
    alpha: Incomplete
    alphaOff: Incomplete
    alphaMod: Incomplete
    hue: Incomplete
    hueOff: Incomplete
    hueMod: Incomplete
    sat: Incomplete
    satOff: Incomplete
    satMod: Incomplete
    lum: Incomplete
    lumOff: Incomplete
    lumMod: Incomplete
    red: Incomplete
    redOff: Incomplete
    redMod: Incomplete
    green: Incomplete
    greenOff: Incomplete
    greenMod: Incomplete
    blue: Incomplete
    blueOff: Incomplete
    blueMod: Incomplete
    gamma: Incomplete
    invGamma: Incomplete
    val: Incomplete
    lastClr: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        val: str = ...,
        lastClr: Incomplete | None = ...,
        tint: Incomplete | None = ...,
        shade: Incomplete | None = ...,
        comp: Incomplete | None = ...,
        inv: Incomplete | None = ...,
        gray: Incomplete | None = ...,
        alpha: Incomplete | None = ...,
        alphaOff: Incomplete | None = ...,
        alphaMod: Incomplete | None = ...,
        hue: Incomplete | None = ...,
        hueOff: Incomplete | None = ...,
        hueMod: Incomplete | None = ...,
        sat: Incomplete | None = ...,
        satOff: Incomplete | None = ...,
        satMod: Incomplete | None = ...,
        lum: Incomplete | None = ...,
        lumOff: Incomplete | None = ...,
        lumMod: Incomplete | None = ...,
        red: Incomplete | None = ...,
        redOff: Incomplete | None = ...,
        redMod: Incomplete | None = ...,
        green: Incomplete | None = ...,
        greenOff: Incomplete | None = ...,
        greenMod: Incomplete | None = ...,
        blue: Incomplete | None = ...,
        blueOff: Incomplete | None = ...,
        blueMod: Incomplete | None = ...,
        gamma: Incomplete | None = ...,
        invGamma: Incomplete | None = ...,
    ) -> None: ...

class HSLColor(Serialisable):
    tagname: str
    hue: Incomplete
    sat: Incomplete
    lum: Incomplete
    def __init__(self, hue: Incomplete | None = ..., sat: Incomplete | None = ..., lum: Incomplete | None = ...) -> None: ...

class RGBPercent(Serialisable):
    tagname: str
    r: Incomplete
    g: Incomplete
    b: Incomplete
    def __init__(self, r: Incomplete | None = ..., g: Incomplete | None = ..., b: Incomplete | None = ...) -> None: ...

class SchemeColor(Serialisable):
    tagname: str
    namespace: Incomplete
    tint: Incomplete
    shade: Incomplete
    comp: Incomplete
    inv: Incomplete
    gray: Incomplete
    alpha: Incomplete
    alphaOff: Incomplete
    alphaMod: Incomplete
    hue: Incomplete
    hueOff: Incomplete
    hueMod: Incomplete
    sat: Incomplete
    satOff: Incomplete
    satMod: Incomplete
    lum: Incomplete
    lumOff: Incomplete
    lumMod: Incomplete
    red: Incomplete
    redOff: Incomplete
    redMod: Incomplete
    green: Incomplete
    greenOff: Incomplete
    greenMod: Incomplete
    blue: Incomplete
    blueOff: Incomplete
    blueMod: Incomplete
    gamma: Incomplete
    invGamma: Incomplete
    val: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        tint: Incomplete | None = ...,
        shade: Incomplete | None = ...,
        comp: Incomplete | None = ...,
        inv: Incomplete | None = ...,
        gray: Incomplete | None = ...,
        alpha: Incomplete | None = ...,
        alphaOff: Incomplete | None = ...,
        alphaMod: Incomplete | None = ...,
        hue: Incomplete | None = ...,
        hueOff: Incomplete | None = ...,
        hueMod: Incomplete | None = ...,
        sat: Incomplete | None = ...,
        satOff: Incomplete | None = ...,
        satMod: Incomplete | None = ...,
        lum: Incomplete | None = ...,
        lumOff: Incomplete | None = ...,
        lumMod: Incomplete | None = ...,
        red: Incomplete | None = ...,
        redOff: Incomplete | None = ...,
        redMod: Incomplete | None = ...,
        green: Incomplete | None = ...,
        greenOff: Incomplete | None = ...,
        greenMod: Incomplete | None = ...,
        blue: Incomplete | None = ...,
        blueOff: Incomplete | None = ...,
        blueMod: Incomplete | None = ...,
        gamma: Incomplete | None = ...,
        invGamma: Incomplete | None = ...,
        val: Incomplete | None = ...,
    ) -> None: ...

class ColorChoice(Serialisable):
    tagname: str
    namespace: Incomplete
    scrgbClr: Incomplete
    RGBPercent: Incomplete
    srgbClr: Incomplete
    RGB: Incomplete
    hslClr: Incomplete
    sysClr: Incomplete
    schemeClr: Incomplete
    prstClr: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        scrgbClr: Incomplete | None = ...,
        srgbClr: Incomplete | None = ...,
        hslClr: Incomplete | None = ...,
        sysClr: Incomplete | None = ...,
        schemeClr: Incomplete | None = ...,
        prstClr: Incomplete | None = ...,
    ) -> None: ...

class ColorMapping(Serialisable):
    tagname: str
    bg1: Incomplete
    tx1: Incomplete
    bg2: Incomplete
    tx2: Incomplete
    accent1: Incomplete
    accent2: Incomplete
    accent3: Incomplete
    accent4: Incomplete
    accent5: Incomplete
    accent6: Incomplete
    hlink: Incomplete
    folHlink: Incomplete
    extLst: Incomplete
    def __init__(
        self,
        bg1: str = ...,
        tx1: str = ...,
        bg2: str = ...,
        tx2: str = ...,
        accent1: str = ...,
        accent2: str = ...,
        accent3: str = ...,
        accent4: str = ...,
        accent5: str = ...,
        accent6: str = ...,
        hlink: str = ...,
        folHlink: str = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class ColorChoiceDescriptor(Typed):
    expected_type: Incomplete
    allow_none: bool
    def __set__(self, instance, value) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class CellSmartTagPr(Serialisable):
    tagname: str
    key: Incomplete
    val: Incomplete
    def __init__(self, key: Incomplete | None = ..., val: Incomplete | None = ...) -> None: ...

class CellSmartTag(Serialisable):
    tagname: str
    cellSmartTagPr: Incomplete
    type: Incomplete
    deleted: Incomplete
    xmlBased: Incomplete
    __elements__: Incomplete
    def __init__(self, cellSmartTagPr=..., type: Incomplete | None = ..., deleted: bool = ..., xmlBased: bool = ...) -> None: ...

class CellSmartTags(Serialisable):
    tagname: str
    cellSmartTag: Incomplete
    r: Incomplete
    __elements__: Incomplete
    def __init__(self, cellSmartTag=..., r: Incomplete | None = ...) -> None: ...

class SmartTags(Serialisable):
    tagname: str
    cellSmartTags: Incomplete
    __elements__: Incomplete
    def __init__(self, cellSmartTags=...) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class PageMargins(Serialisable):
    tagname: str
    l: Incomplete
    left: Incomplete
    r: Incomplete
    right: Incomplete
    t: Incomplete
    top: Incomplete
    b: Incomplete
    bottom: Incomplete
    header: Incomplete
    footer: Incomplete
    def __init__(
        self, l: float = ..., r: float = ..., t: int = ..., b: int = ..., header: float = ..., footer: float = ...
    ) -> None: ...

class PrintSettings(Serialisable):
    tagname: str
    headerFooter: Incomplete
    pageMargins: Incomplete
    pageSetup: Incomplete
    __elements__: Incomplete
    def __init__(
        self, headerFooter: Incomplete | None = ..., pageMargins: Incomplete | None = ..., pageSetup: Incomplete | None = ...
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class PivotSource(Serialisable):
    tagname: str
    name: Incomplete
    fmtId: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self, name: Incomplete | None = ..., fmtId: Incomplete | None = ..., extLst: Incomplete | None = ...
    ) -> None: ...

class PivotFormat(Serialisable):
    tagname: str
    idx: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    txPr: Incomplete
    TextBody: Incomplete
    marker: Incomplete
    dLbl: Incomplete
    DataLabel: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        idx: int = ...,
        spPr: Incomplete | None = ...,
        txPr: Incomplete | None = ...,
        marker: Incomplete | None = ...,
        dLbl: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

def get_version(): ...

class DigSigBlob(Serialisable):  # type: ignore[misc]
    __elements__: Incomplete
    __attrs__: Incomplete

class VectorLpstr(Serialisable):  # type: ignore[misc]
    __elements__: Incomplete
    __attrs__: Incomplete

class VectorVariant(Serialisable):  # type: ignore[misc]
    __elements__: Incomplete
    __attrs__: Incomplete

class ExtendedProperties(Serialisable):
    tagname: str
    Template: Incomplete
    Manager: Incomplete
    Company: Incomplete
    Pages: Incomplete
    Words: Incomplete
    Characters: Incomplete
    PresentationFormat: Incomplete
    Lines: Incomplete
    Paragraphs: Incomplete
    Slides: Incomplete
    Notes: Incomplete
    TotalTime: Incomplete
    HiddenSlides: Incomplete
    MMClips: Incomplete
    ScaleCrop: Incomplete
    HeadingPairs: Incomplete
    TitlesOfParts: Incomplete
    LinksUpToDate: Incomplete
    CharactersWithSpaces: Incomplete
    SharedDoc: Incomplete
    HyperlinkBase: Incomplete
    HLinks: Incomplete
    HyperlinksChanged: Incomplete
    DigSig: Incomplete
    Application: Incomplete
    AppVersion: Incomplete
    DocSecurity: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        Template: Incomplete | None = ...,
        Manager: Incomplete | None = ...,
        Company: Incomplete | None = ...,
        Pages: Incomplete | None = ...,
        Words: Incomplete | None = ...,
        Characters: Incomplete | None = ...,
        PresentationFormat: Incomplete | None = ...,
        Lines: Incomplete | None = ...,
        Paragraphs: Incomplete | None = ...,
        Slides: Incomplete | None = ...,
        Notes: Incomplete | None = ...,
        TotalTime: Incomplete | None = ...,
        HiddenSlides: Incomplete | None = ...,
        MMClips: Incomplete | None = ...,
        ScaleCrop: Incomplete | None = ...,
        HeadingPairs: Incomplete | None = ...,
        TitlesOfParts: Incomplete | None = ...,
        LinksUpToDate: Incomplete | None = ...,
        CharactersWithSpaces: Incomplete | None = ...,
        SharedDoc: Incomplete | None = ...,
        HyperlinkBase: Incomplete | None = ...,
        HLinks: Incomplete | None = ...,
        HyperlinksChanged: Incomplete | None = ...,
        DigSig: Incomplete | None = ...,
        Application: str = ...,
        AppVersion: Incomplete | None = ...,
        DocSecurity: Incomplete | None = ...,
    ) -> None: ...
    def to_tree(self): ...



from _typeshed import Incomplete
from collections.abc import Generator

from openpyxl.descriptors import Strict
from openpyxl.descriptors.serialisable import Serialisable

class CellRange(Serialisable):  # type: ignore[misc]
    min_col: Incomplete
    min_row: Incomplete
    max_col: Incomplete
    max_row: Incomplete
    title: Incomplete
    def __init__(
        self,
        range_string: Incomplete | None = ...,
        min_col: Incomplete | None = ...,
        min_row: Incomplete | None = ...,
        max_col: Incomplete | None = ...,
        max_row: Incomplete | None = ...,
        title: Incomplete | None = ...,
    ) -> None: ...
    @property
    def bounds(self): ...
    @property
    def coord(self): ...
    @property
    def rows(self) -> Generator[Incomplete, None, None]: ...
    @property
    def cols(self) -> Generator[Incomplete, None, None]: ...
    @property
    def cells(self): ...
    def __copy__(self): ...
    def shift(self, col_shift: int = ..., row_shift: int = ...) -> None: ...
    def __ne__(self, other): ...
    def __eq__(self, other): ...
    def issubset(self, other): ...
    __le__: Incomplete
    def __lt__(self, other): ...
    def issuperset(self, other): ...
    __ge__: Incomplete
    def __contains__(self, coord): ...
    def __gt__(self, other): ...
    def isdisjoint(self, other): ...
    def intersection(self, other): ...
    __and__: Incomplete
    def union(self, other): ...
    __or__: Incomplete
    def __iter__(self): ...
    def expand(self, right: int = ..., down: int = ..., left: int = ..., up: int = ...) -> None: ...
    def shrink(self, right: int = ..., bottom: int = ..., left: int = ..., top: int = ...) -> None: ...
    @property
    def size(self): ...
    @property
    def top(self): ...
    @property
    def bottom(self): ...
    @property
    def left(self): ...
    @property
    def right(self): ...

class MultiCellRange(Strict):
    ranges: Incomplete
    def __init__(self, ranges=...) -> None: ...
    def __contains__(self, coord): ...
    def add(self, coord) -> None: ...
    def __iadd__(self, coord): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __bool__(self) -> bool: ...
    def remove(self, coord) -> None: ...
    def __iter__(self): ...
    def __copy__(self): ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class ExternalCell(Serialisable):  # type: ignore[misc]
    r: Incomplete
    t: Incomplete
    vm: Incomplete
    v: Incomplete
    def __init__(
        self, r: Incomplete | None = ..., t: Incomplete | None = ..., vm: Incomplete | None = ..., v: Incomplete | None = ...
    ) -> None: ...

class ExternalRow(Serialisable):  # type: ignore[misc]
    r: Incomplete
    cell: Incomplete
    __elements__: Incomplete
    def __init__(self, r=..., cell: Incomplete | None = ...) -> None: ...

class ExternalSheetData(Serialisable):  # type: ignore[misc]
    sheetId: Incomplete
    refreshError: Incomplete
    row: Incomplete
    __elements__: Incomplete
    def __init__(self, sheetId: Incomplete | None = ..., refreshError: Incomplete | None = ..., row=...) -> None: ...

class ExternalSheetDataSet(Serialisable):  # type: ignore[misc]
    sheetData: Incomplete
    __elements__: Incomplete
    def __init__(self, sheetData: Incomplete | None = ...) -> None: ...

class ExternalSheetNames(Serialisable):  # type: ignore[misc]
    sheetName: Incomplete
    __elements__: Incomplete
    def __init__(self, sheetName=...) -> None: ...

class ExternalDefinedName(Serialisable):
    tagname: str
    name: Incomplete
    refersTo: Incomplete
    sheetId: Incomplete
    def __init__(
        self, name: Incomplete | None = ..., refersTo: Incomplete | None = ..., sheetId: Incomplete | None = ...
    ) -> None: ...

class ExternalBook(Serialisable):
    tagname: str
    sheetNames: Incomplete
    definedNames: Incomplete
    sheetDataSet: Incomplete
    id: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        sheetNames: Incomplete | None = ...,
        definedNames=...,
        sheetDataSet: Incomplete | None = ...,
        id: Incomplete | None = ...,
    ) -> None: ...

class ExternalLink(Serialisable):
    tagname: str
    mime_type: str
    externalBook: Incomplete
    file_link: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        externalBook: Incomplete | None = ...,
        ddeLink: Incomplete | None = ...,
        oleLink: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...
    def to_tree(self): ...
    @property
    def path(self): ...

def read_external_link(archive, book_path): ...



from _typeshed import Incomplete

SUPPORTED_FORMATS: Incomplete

class ExcelReader:
    archive: Incomplete
    valid_files: Incomplete
    read_only: Incomplete
    keep_vba: Incomplete
    data_only: Incomplete
    keep_links: Incomplete
    shared_strings: Incomplete
    def __init__(self, fn, read_only: bool = ..., keep_vba=..., data_only: bool = ..., keep_links: bool = ...) -> None: ...
    package: Incomplete
    def read_manifest(self) -> None: ...
    def read_strings(self) -> None: ...
    parser: Incomplete
    wb: Incomplete
    def read_workbook(self) -> None: ...
    def read_properties(self) -> None: ...
    def read_theme(self) -> None: ...
    def read_chartsheet(self, sheet, rel) -> None: ...
    def read_worksheets(self) -> None: ...
    def read(self) -> None: ...

def load_workbook(filename, read_only: bool = ..., keep_vba=..., data_only: bool = ..., keep_links: bool = ...): ...



from _typeshed import Incomplete

INTEGER_TYPES: Incomplete

class Workbook:
    template: bool
    path: str
    defined_names: Incomplete
    properties: Incomplete
    security: Incomplete
    shared_strings: Incomplete
    loaded_theme: Incomplete
    vba_archive: Incomplete
    is_template: bool
    code_name: Incomplete
    encoding: str
    iso_dates: Incomplete
    rels: Incomplete
    calculation: Incomplete
    views: Incomplete
    def __init__(self, write_only: bool = ..., iso_dates: bool = ...) -> None: ...
    @property
    def epoch(self): ...
    @epoch.setter
    def epoch(self, value) -> None: ...
    @property
    def read_only(self): ...
    @property
    def data_only(self): ...
    @property
    def write_only(self): ...
    @property
    def excel_base_date(self): ...
    @property
    def active(self): ...
    @active.setter
    def active(self, value) -> None: ...
    def create_sheet(self, title: Incomplete | None = ..., index: Incomplete | None = ...): ...
    def move_sheet(self, sheet, offset: int = ...) -> None: ...
    def remove(self, worksheet) -> None: ...
    def remove_sheet(self, worksheet) -> None: ...
    def create_chartsheet(self, title: Incomplete | None = ..., index: Incomplete | None = ...): ...
    def get_sheet_by_name(self, name): ...
    def __contains__(self, key): ...
    def index(self, worksheet): ...
    def get_index(self, worksheet): ...
    def __getitem__(self, key): ...
    def __delitem__(self, key) -> None: ...
    def __iter__(self): ...
    def get_sheet_names(self): ...
    @property
    def worksheets(self): ...
    @property
    def chartsheets(self): ...
    @property
    def sheetnames(self): ...
    def create_named_range(
        self, name, worksheet: Incomplete | None = ..., value: Incomplete | None = ..., scope: Incomplete | None = ...
    ) -> None: ...
    def add_named_style(self, style) -> None: ...
    @property
    def named_styles(self): ...
    def get_named_ranges(self): ...
    def add_named_range(self, named_range) -> None: ...
    def get_named_range(self, name): ...
    def remove_named_range(self, named_range) -> None: ...
    @property
    def mime_type(self): ...
    def save(self, filename) -> None: ...
    @property
    def style_names(self): ...
    def copy_worksheet(self, from_worksheet): ...
    def close(self) -> None: ...



from _typeshed import Incomplete

from ._chart import ChartBase

class RadarChart(ChartBase):
    tagname: str
    radarStyle: Incomplete
    type: Incomplete
    varyColors: Incomplete
    ser: Incomplete
    dLbls: Incomplete
    dataLabels: Incomplete
    extLst: Incomplete
    x_axis: Incomplete
    y_axis: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        radarStyle: str = ...,
        varyColors: Incomplete | None = ...,
        ser=...,
        dLbls: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
        **kw,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors import DateTime
from openpyxl.descriptors.nested import NestedText
from openpyxl.descriptors.serialisable import Serialisable

class NestedDateTime(DateTime, NestedText):
    expected_type: Incomplete
    def to_tree(self, tagname: Incomplete | None = ..., value: Incomplete | None = ..., namespace: Incomplete | None = ...): ...

class QualifiedDateTime(NestedDateTime):
    def to_tree(self, tagname: Incomplete | None = ..., value: Incomplete | None = ..., namespace: Incomplete | None = ...): ...

class DocumentProperties(Serialisable):
    tagname: str
    namespace: Incomplete
    category: Incomplete
    contentStatus: Incomplete
    keywords: Incomplete
    lastModifiedBy: Incomplete
    lastPrinted: Incomplete
    revision: Incomplete
    version: Incomplete
    last_modified_by: Incomplete
    subject: Incomplete
    title: Incomplete
    creator: Incomplete
    description: Incomplete
    identifier: Incomplete
    language: Incomplete
    created: Incomplete
    modified: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        category: Incomplete | None = ...,
        contentStatus: Incomplete | None = ...,
        keywords: Incomplete | None = ...,
        lastModifiedBy: Incomplete | None = ...,
        lastPrinted: Incomplete | None = ...,
        revision: Incomplete | None = ...,
        version: Incomplete | None = ...,
        created=...,
        creator: str = ...,
        description: Incomplete | None = ...,
        identifier: Incomplete | None = ...,
        language: Incomplete | None = ...,
        modified=...,
        subject: Incomplete | None = ...,
        title: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable
from openpyxl.worksheet.protection import _Protected

class ChartsheetProtection(Serialisable, _Protected):
    tagname: str
    algorithmName: Incomplete
    hashValue: Incomplete
    saltValue: Incomplete
    spinCount: Incomplete
    content: Incomplete
    objects: Incomplete
    __attrs__: Incomplete
    password: Incomplete
    def __init__(
        self,
        content: Incomplete | None = ...,
        objects: Incomplete | None = ...,
        hashValue: Incomplete | None = ...,
        spinCount: Incomplete | None = ...,
        saltValue: Incomplete | None = ...,
        algorithmName: Incomplete | None = ...,
        password: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class AnchorClientData(Serialisable):
    fLocksWithSheet: Incomplete
    fPrintsWithSheet: Incomplete
    def __init__(self, fLocksWithSheet: Incomplete | None = ..., fPrintsWithSheet: Incomplete | None = ...) -> None: ...

class AnchorMarker(Serialisable):
    tagname: str
    col: Incomplete
    colOff: Incomplete
    row: Incomplete
    rowOff: Incomplete
    def __init__(self, col: int = ..., colOff: int = ..., row: int = ..., rowOff: int = ...) -> None: ...

class _AnchorBase(Serialisable):
    sp: Incomplete
    shape: Incomplete
    grpSp: Incomplete
    groupShape: Incomplete
    graphicFrame: Incomplete
    cxnSp: Incomplete
    connectionShape: Incomplete
    pic: Incomplete
    contentPart: Incomplete
    clientData: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        clientData: Incomplete | None = ...,
        sp: Incomplete | None = ...,
        grpSp: Incomplete | None = ...,
        graphicFrame: Incomplete | None = ...,
        cxnSp: Incomplete | None = ...,
        pic: Incomplete | None = ...,
        contentPart: Incomplete | None = ...,
    ) -> None: ...

class AbsoluteAnchor(_AnchorBase):
    tagname: str
    pos: Incomplete
    ext: Incomplete
    sp: Incomplete
    grpSp: Incomplete
    graphicFrame: Incomplete
    cxnSp: Incomplete
    pic: Incomplete
    contentPart: Incomplete
    clientData: Incomplete
    __elements__: Incomplete
    def __init__(self, pos: Incomplete | None = ..., ext: Incomplete | None = ..., **kw) -> None: ...

class OneCellAnchor(_AnchorBase):
    tagname: str
    ext: Incomplete
    sp: Incomplete
    grpSp: Incomplete
    graphicFrame: Incomplete
    cxnSp: Incomplete
    pic: Incomplete
    contentPart: Incomplete
    clientData: Incomplete
    __elements__: Incomplete
    def __init__(self, _from: Incomplete | None = ..., ext: Incomplete | None = ..., **kw) -> None: ...

class TwoCellAnchor(_AnchorBase):
    tagname: str
    editAs: Incomplete
    to: Incomplete
    sp: Incomplete
    grpSp: Incomplete
    graphicFrame: Incomplete
    cxnSp: Incomplete
    pic: Incomplete
    contentPart: Incomplete
    clientData: Incomplete
    __elements__: Incomplete
    def __init__(
        self, editAs: Incomplete | None = ..., _from: Incomplete | None = ..., to: Incomplete | None = ..., **kw
    ) -> None: ...

class SpreadsheetDrawing(Serialisable):
    tagname: str
    mime_type: str
    PartName: str
    twoCellAnchor: Incomplete
    oneCellAnchor: Incomplete
    absoluteAnchor: Incomplete
    __elements__: Incomplete
    charts: Incomplete
    images: Incomplete
    def __init__(self, twoCellAnchor=..., oneCellAnchor=..., absoluteAnchor=...) -> None: ...
    def __hash__(self) -> int: ...
    def __bool__(self) -> bool: ...
    @property
    def path(self): ...



from _typeshed import Incomplete
from collections.abc import Generator

class WorkbookParser:
    archive: Incomplete
    workbook_part_name: Incomplete
    wb: Incomplete
    keep_links: Incomplete
    sheets: Incomplete
    def __init__(self, archive, workbook_part_name, keep_links: bool = ...) -> None: ...
    @property
    def rels(self): ...
    caches: Incomplete
    def parse(self) -> None: ...
    def find_sheets(self) -> Generator[Incomplete, None, None]: ...
    def assign_names(self) -> None: ...
    @property
    def pivot_caches(self): ...



from _typeshed import Incomplete

class Descriptor:
    name: Incomplete
    def __init__(self, name: Incomplete | None = ..., **kw) -> None: ...
    def __set__(self, instance, value) -> None: ...

class Typed(Descriptor):
    expected_type: Incomplete
    allow_none: bool
    nested: bool
    __doc__: Incomplete
    def __init__(self, *args, **kw) -> None: ...
    def __set__(self, instance, value) -> None: ...

class Convertible(Typed):
    def __set__(self, instance, value) -> None: ...

class Max(Convertible):
    expected_type: Incomplete
    allow_none: bool
    def __init__(self, **kw) -> None: ...
    def __set__(self, instance, value) -> None: ...

class Min(Convertible):
    expected_type: Incomplete
    allow_none: bool
    def __init__(self, **kw) -> None: ...
    def __set__(self, instance, value) -> None: ...

class MinMax(Min, Max): ...

class Set(Descriptor):
    __doc__: Incomplete
    def __init__(self, name: Incomplete | None = ..., **kw) -> None: ...
    def __set__(self, instance, value) -> None: ...

class NoneSet(Set):
    def __init__(self, name: Incomplete | None = ..., **kw) -> None: ...
    def __set__(self, instance, value) -> None: ...

class Integer(Convertible):
    expected_type: Incomplete

class Float(Convertible):
    expected_type: Incomplete

class Bool(Convertible):
    expected_type: Incomplete
    def __set__(self, instance, value) -> None: ...

class String(Typed):
    expected_type: Incomplete

class Text(String, Convertible): ...

class ASCII(Typed):
    expected_type: Incomplete

class Tuple(Typed):
    expected_type: Incomplete

class Length(Descriptor):
    def __init__(self, name: Incomplete | None = ..., **kw) -> None: ...
    def __set__(self, instance, value) -> None: ...

class Default(Typed):
    def __init__(self, name: Incomplete | None = ..., **kw) -> None: ...
    def __call__(self): ...

class Alias(Descriptor):
    alias: Incomplete
    def __init__(self, alias) -> None: ...
    def __set__(self, instance, value) -> None: ...
    def __get__(self, instance, cls): ...

class MatchPattern(Descriptor):
    allow_none: bool
    test_pattern: Incomplete
    def __init__(self, name: Incomplete | None = ..., **kw) -> None: ...
    def __set__(self, instance, value) -> None: ...

class DateTime(Typed):
    expected_type: Incomplete
    def __set__(self, instance, value) -> None: ...



from _typeshed import Incomplete
from abc import abstractmethod

from openpyxl.descriptors.serialisable import Serialisable

class AxId(Serialisable):  # type: ignore[misc]
    val: Incomplete
    def __init__(self, val) -> None: ...

def PlotArea(): ...

class ChartBase(Serialisable):
    legend: Incomplete
    layout: Incomplete
    roundedCorners: Incomplete
    axId: Incomplete
    visible_cells_only: Incomplete
    display_blanks: Incomplete
    ser: Incomplete
    series: Incomplete
    title: Incomplete
    anchor: str
    width: int
    height: float
    style: Incomplete
    mime_type: str
    graphical_properties: Incomplete
    __elements__: Incomplete
    plot_area: Incomplete
    pivotSource: Incomplete
    pivotFormats: Incomplete
    idx_base: int
    def __init__(self, axId=..., **kw) -> None: ...
    def __hash__(self) -> int: ...
    def __iadd__(self, other): ...
    def to_tree(self, namespace: Incomplete | None = ..., tagname: Incomplete | None = ..., idx: Incomplete | None = ...): ...  # type: ignore[override]
    def set_categories(self, labels) -> None: ...
    def add_data(self, data, from_rows: bool = ..., titles_from_data: bool = ...) -> None: ...
    def append(self, value) -> None: ...
    @property
    def path(self): ...
    @property
    @abstractmethod
    def tagname(self) -> str: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class Stylesheet(Serialisable):
    tagname: str
    numFmts: Incomplete
    fonts: Incomplete
    fills: Incomplete
    borders: Incomplete
    cellStyleXfs: Incomplete
    cellXfs: Incomplete
    cellStyles: Incomplete
    dxfs: Incomplete
    tableStyles: Incomplete
    colors: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    number_formats: Incomplete
    cell_styles: Incomplete
    alignments: Incomplete
    protections: Incomplete
    named_styles: Incomplete
    def __init__(
        self,
        numFmts: Incomplete | None = ...,
        fonts=...,
        fills=...,
        borders=...,
        cellStyleXfs: Incomplete | None = ...,
        cellXfs: Incomplete | None = ...,
        cellStyles: Incomplete | None = ...,
        dxfs=...,
        tableStyles: Incomplete | None = ...,
        colors: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...
    @classmethod
    def from_tree(cls, node): ...
    @property
    def custom_formats(self): ...
    def to_tree(self, tagname: Incomplete | None = ..., idx: Incomplete | None = ..., namespace: Incomplete | None = ...): ...

def apply_stylesheet(archive, wb): ...
def write_stylesheet(wb): ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class ChartContainer(Serialisable):
    tagname: str
    title: Incomplete
    autoTitleDeleted: Incomplete
    pivotFmts: Incomplete
    view3D: Incomplete
    floor: Incomplete
    sideWall: Incomplete
    backWall: Incomplete
    plotArea: Incomplete
    legend: Incomplete
    plotVisOnly: Incomplete
    dispBlanksAs: Incomplete
    showDLblsOverMax: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        title: Incomplete | None = ...,
        autoTitleDeleted: Incomplete | None = ...,
        pivotFmts=...,
        view3D: Incomplete | None = ...,
        floor: Incomplete | None = ...,
        sideWall: Incomplete | None = ...,
        backWall: Incomplete | None = ...,
        plotArea: Incomplete | None = ...,
        legend: Incomplete | None = ...,
        plotVisOnly: bool = ...,
        dispBlanksAs: str = ...,
        showDLblsOverMax: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class Protection(Serialisable):
    tagname: str
    chartObject: Incomplete
    data: Incomplete
    formatting: Incomplete
    selection: Incomplete
    userInterface: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        chartObject: Incomplete | None = ...,
        data: Incomplete | None = ...,
        formatting: Incomplete | None = ...,
        selection: Incomplete | None = ...,
        userInterface: Incomplete | None = ...,
    ) -> None: ...

class ExternalData(Serialisable):
    tagname: str
    autoUpdate: Incomplete
    id: Incomplete
    def __init__(self, autoUpdate: Incomplete | None = ..., id: Incomplete | None = ...) -> None: ...

class ChartSpace(Serialisable):
    tagname: str
    date1904: Incomplete
    lang: Incomplete
    roundedCorners: Incomplete
    style: Incomplete
    clrMapOvr: Incomplete
    pivotSource: Incomplete
    protection: Incomplete
    chart: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    txPr: Incomplete
    textProperties: Incomplete
    externalData: Incomplete
    printSettings: Incomplete
    userShapes: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        date1904: Incomplete | None = ...,
        lang: Incomplete | None = ...,
        roundedCorners: Incomplete | None = ...,
        style: Incomplete | None = ...,
        clrMapOvr: Incomplete | None = ...,
        pivotSource: Incomplete | None = ...,
        protection: Incomplete | None = ...,
        chart: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        txPr: Incomplete | None = ...,
        externalData: Incomplete | None = ...,
        printSettings: Incomplete | None = ...,
        userShapes: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...
    def to_tree(self, tagname: Incomplete | None = ..., idx: Incomplete | None = ..., namespace: Incomplete | None = ...): ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

BORDER_NONE: Incomplete
BORDER_DASHDOT: str
BORDER_DASHDOTDOT: str
BORDER_DASHED: str
BORDER_DOTTED: str
BORDER_DOUBLE: str
BORDER_HAIR: str
BORDER_MEDIUM: str
BORDER_MEDIUMDASHDOT: str
BORDER_MEDIUMDASHDOTDOT: str
BORDER_MEDIUMDASHED: str
BORDER_SLANTDASHDOT: str
BORDER_THICK: str
BORDER_THIN: str

class Side(Serialisable):  # type: ignore[misc]
    __fields__: Incomplete
    color: Incomplete
    style: Incomplete
    border_style: Incomplete
    def __init__(
        self, style: Incomplete | None = ..., color: Incomplete | None = ..., border_style: Incomplete | None = ...
    ) -> None: ...

class Border(Serialisable):
    tagname: str
    __fields__: Incomplete
    __elements__: Incomplete
    start: Incomplete
    end: Incomplete
    left: Incomplete
    right: Incomplete
    top: Incomplete
    bottom: Incomplete
    diagonal: Incomplete
    vertical: Incomplete
    horizontal: Incomplete
    outline: Incomplete
    diagonalUp: Incomplete
    diagonalDown: Incomplete
    diagonal_direction: Incomplete
    def __init__(
        self,
        left: Incomplete | None = ...,
        right: Incomplete | None = ...,
        top: Incomplete | None = ...,
        bottom: Incomplete | None = ...,
        diagonal: Incomplete | None = ...,
        diagonal_direction: Incomplete | None = ...,
        vertical: Incomplete | None = ...,
        horizontal: Incomplete | None = ...,
        diagonalUp: bool = ...,
        diagonalDown: bool = ...,
        outline: bool = ...,
        start: Incomplete | None = ...,
        end: Incomplete | None = ...,
    ) -> None: ...
    def __iter__(self): ...

DEFAULT_BORDER: Incomplete



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class View3D(Serialisable):
    tagname: str
    rotX: Incomplete
    x_rotation: Incomplete
    hPercent: Incomplete
    height_percent: Incomplete
    rotY: Incomplete
    y_rotation: Incomplete
    depthPercent: Incomplete
    rAngAx: Incomplete
    right_angle_axes: Incomplete
    perspective: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        rotX: int = ...,
        hPercent: Incomplete | None = ...,
        rotY: int = ...,
        depthPercent: Incomplete | None = ...,
        rAngAx: bool = ...,
        perspective: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class Surface(Serialisable):
    tagname: str
    thickness: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    pictureOptions: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        thickness: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        pictureOptions: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class _3DBase(Serialisable):
    tagname: str
    view3D: Incomplete
    floor: Incomplete
    sideWall: Incomplete
    backWall: Incomplete
    def __init__(
        self,
        view3D: Incomplete | None = ...,
        floor: Incomplete | None = ...,
        sideWall: Incomplete | None = ...,
        backWall: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class Marker(Serialisable):
    tagname: str
    symbol: Incomplete
    size: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        symbol: Incomplete | None = ...,
        size: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class DataPoint(Serialisable):
    tagname: str
    idx: Incomplete
    invertIfNegative: Incomplete
    marker: Incomplete
    bubble3D: Incomplete
    explosion: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    pictureOptions: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        idx: Incomplete | None = ...,
        invertIfNegative: Incomplete | None = ...,
        marker: Incomplete | None = ...,
        bubble3D: Incomplete | None = ...,
        explosion: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        pictureOptions: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

from .colors import ColorChoice

class TintEffect(Serialisable):
    tagname: str
    hue: Incomplete
    amt: Incomplete
    def __init__(self, hue: int = ..., amt: int = ...) -> None: ...

class LuminanceEffect(Serialisable):
    tagname: str
    bright: Incomplete
    contrast: Incomplete
    def __init__(self, bright: int = ..., contrast: int = ...) -> None: ...

class HSLEffect(Serialisable):
    hue: Incomplete
    sat: Incomplete
    lum: Incomplete
    def __init__(self, hue: Incomplete | None = ..., sat: Incomplete | None = ..., lum: Incomplete | None = ...) -> None: ...

class GrayscaleEffect(Serialisable):
    tagname: str

class FillOverlayEffect(Serialisable):
    blend: Incomplete
    def __init__(self, blend: Incomplete | None = ...) -> None: ...

class DuotoneEffect(Serialisable): ...
class ColorReplaceEffect(Serialisable): ...
class Color(Serialisable): ...

class ColorChangeEffect(Serialisable):
    useA: Incomplete
    clrFrom: Incomplete
    clrTo: Incomplete
    def __init__(
        self, useA: Incomplete | None = ..., clrFrom: Incomplete | None = ..., clrTo: Incomplete | None = ...
    ) -> None: ...

class BlurEffect(Serialisable):
    rad: Incomplete
    grow: Incomplete
    def __init__(self, rad: Incomplete | None = ..., grow: Incomplete | None = ...) -> None: ...

class BiLevelEffect(Serialisable):
    thresh: Incomplete
    def __init__(self, thresh: Incomplete | None = ...) -> None: ...

class AlphaReplaceEffect(Serialisable):
    a: Incomplete
    def __init__(self, a: Incomplete | None = ...) -> None: ...

class AlphaModulateFixedEffect(Serialisable):
    amt: Incomplete
    def __init__(self, amt: Incomplete | None = ...) -> None: ...

class EffectContainer(Serialisable):
    type: Incomplete
    name: Incomplete
    def __init__(self, type: Incomplete | None = ..., name: Incomplete | None = ...) -> None: ...

class AlphaModulateEffect(Serialisable):
    cont: Incomplete
    def __init__(self, cont: Incomplete | None = ...) -> None: ...

class AlphaInverseEffect(Serialisable): ...
class AlphaFloorEffect(Serialisable): ...
class AlphaCeilingEffect(Serialisable): ...

class AlphaBiLevelEffect(Serialisable):
    thresh: Incomplete
    def __init__(self, thresh: Incomplete | None = ...) -> None: ...

class GlowEffect(ColorChoice):
    rad: Incomplete
    scrgbClr: Incomplete
    srgbClr: Incomplete
    hslClr: Incomplete
    sysClr: Incomplete
    schemeClr: Incomplete
    prstClr: Incomplete
    __elements__: Incomplete
    def __init__(self, rad: Incomplete | None = ..., **kw) -> None: ...

class InnerShadowEffect(ColorChoice):
    blurRad: Incomplete
    dist: Incomplete
    dir: Incomplete
    scrgbClr: Incomplete
    srgbClr: Incomplete
    hslClr: Incomplete
    sysClr: Incomplete
    schemeClr: Incomplete
    prstClr: Incomplete
    __elements__: Incomplete
    def __init__(
        self, blurRad: Incomplete | None = ..., dist: Incomplete | None = ..., dir: Incomplete | None = ..., **kw
    ) -> None: ...

class OuterShadow(ColorChoice):
    tagname: str
    blurRad: Incomplete
    dist: Incomplete
    dir: Incomplete
    sx: Incomplete
    sy: Incomplete
    kx: Incomplete
    ky: Incomplete
    algn: Incomplete
    rotWithShape: Incomplete
    scrgbClr: Incomplete
    srgbClr: Incomplete
    hslClr: Incomplete
    sysClr: Incomplete
    schemeClr: Incomplete
    prstClr: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        blurRad: Incomplete | None = ...,
        dist: Incomplete | None = ...,
        dir: Incomplete | None = ...,
        sx: Incomplete | None = ...,
        sy: Incomplete | None = ...,
        kx: Incomplete | None = ...,
        ky: Incomplete | None = ...,
        algn: Incomplete | None = ...,
        rotWithShape: Incomplete | None = ...,
        **kw,
    ) -> None: ...

class PresetShadowEffect(ColorChoice):
    prst: Incomplete
    dist: Incomplete
    dir: Incomplete
    scrgbClr: Incomplete
    srgbClr: Incomplete
    hslClr: Incomplete
    sysClr: Incomplete
    schemeClr: Incomplete
    prstClr: Incomplete
    __elements__: Incomplete
    def __init__(
        self, prst: Incomplete | None = ..., dist: Incomplete | None = ..., dir: Incomplete | None = ..., **kw
    ) -> None: ...

class ReflectionEffect(Serialisable):
    blurRad: Incomplete
    stA: Incomplete
    stPos: Incomplete
    endA: Incomplete
    endPos: Incomplete
    dist: Incomplete
    dir: Incomplete
    fadeDir: Incomplete
    sx: Incomplete
    sy: Incomplete
    kx: Incomplete
    ky: Incomplete
    algn: Incomplete
    rotWithShape: Incomplete
    def __init__(
        self,
        blurRad: Incomplete | None = ...,
        stA: Incomplete | None = ...,
        stPos: Incomplete | None = ...,
        endA: Incomplete | None = ...,
        endPos: Incomplete | None = ...,
        dist: Incomplete | None = ...,
        dir: Incomplete | None = ...,
        fadeDir: Incomplete | None = ...,
        sx: Incomplete | None = ...,
        sy: Incomplete | None = ...,
        kx: Incomplete | None = ...,
        ky: Incomplete | None = ...,
        algn: Incomplete | None = ...,
        rotWithShape: Incomplete | None = ...,
    ) -> None: ...

class SoftEdgesEffect(Serialisable):
    rad: Incomplete
    def __init__(self, rad: Incomplete | None = ...) -> None: ...

class EffectList(Serialisable):
    blur: Incomplete
    fillOverlay: Incomplete
    glow: Incomplete
    innerShdw: Incomplete
    outerShdw: Incomplete
    prstShdw: Incomplete
    reflection: Incomplete
    softEdge: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        blur: Incomplete | None = ...,
        fillOverlay: Incomplete | None = ...,
        glow: Incomplete | None = ...,
        innerShdw: Incomplete | None = ...,
        outerShdw: Incomplete | None = ...,
        prstShdw: Incomplete | None = ...,
        reflection: Incomplete | None = ...,
        softEdge: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete
from collections.abc import Generator

CELL_TAG: Incomplete
VALUE_TAG: Incomplete
FORMULA_TAG: Incomplete
MERGE_TAG: Incomplete
INLINE_STRING: Incomplete
COL_TAG: Incomplete
ROW_TAG: Incomplete
CF_TAG: Incomplete
LEGACY_TAG: Incomplete
PROT_TAG: Incomplete
EXT_TAG: Incomplete
HYPERLINK_TAG: Incomplete
TABLE_TAG: Incomplete
PRINT_TAG: Incomplete
MARGINS_TAG: Incomplete
PAGE_TAG: Incomplete
HEADER_TAG: Incomplete
FILTER_TAG: Incomplete
VALIDATION_TAG: Incomplete
PROPERTIES_TAG: Incomplete
VIEWS_TAG: Incomplete
FORMAT_TAG: Incomplete
ROW_BREAK_TAG: Incomplete
COL_BREAK_TAG: Incomplete
SCENARIOS_TAG: Incomplete
DATA_TAG: Incomplete
DIMENSION_TAG: Incomplete
CUSTOM_VIEWS_TAG: Incomplete

class WorkSheetParser:
    min_row: Incomplete
    epoch: Incomplete
    source: Incomplete
    shared_strings: Incomplete
    data_only: Incomplete
    shared_formulae: Incomplete
    array_formulae: Incomplete
    row_counter: int
    tables: Incomplete
    date_formats: Incomplete
    timedelta_formats: Incomplete
    row_dimensions: Incomplete
    column_dimensions: Incomplete
    number_formats: Incomplete
    keep_vba: bool
    hyperlinks: Incomplete
    formatting: Incomplete
    legacy_drawing: Incomplete
    merged_cells: Incomplete
    row_breaks: Incomplete
    col_breaks: Incomplete
    def __init__(
        self, src, shared_strings, data_only: bool = ..., epoch=..., date_formats=..., timedelta_formats=...
    ) -> None: ...
    def parse(self) -> Generator[Incomplete, None, None]: ...
    def parse_dimensions(self): ...
    col_counter: Incomplete
    def parse_cell(self, element): ...
    def parse_formula(self, element): ...
    def parse_column_dimensions(self, col) -> None: ...
    def parse_row(self, row): ...
    def parse_formatting(self, element) -> None: ...
    protection: Incomplete
    def parse_sheet_protection(self, element) -> None: ...
    def parse_extensions(self, element) -> None: ...
    def parse_legacy(self, element) -> None: ...
    def parse_row_breaks(self, element) -> None: ...
    def parse_col_breaks(self, element) -> None: ...
    def parse_custom_views(self, element) -> None: ...

class WorksheetReader:
    ws: Incomplete
    parser: Incomplete
    tables: Incomplete
    def __init__(self, ws, xml_source, shared_strings, data_only) -> None: ...
    def bind_cells(self) -> None: ...
    def bind_formatting(self) -> None: ...
    def bind_tables(self) -> None: ...
    def bind_merged_cells(self) -> None: ...
    def bind_hyperlinks(self) -> None: ...
    def normalize_merged_cell_link(self, coord): ...
    def bind_col_dimensions(self) -> None: ...
    def bind_row_dimensions(self) -> None: ...
    def bind_properties(self) -> None: ...
    def bind_all(self) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class Pane(Serialisable):  # type: ignore[misc]
    xSplit: Incomplete
    ySplit: Incomplete
    topLeftCell: Incomplete
    activePane: Incomplete
    state: Incomplete
    def __init__(
        self,
        xSplit: Incomplete | None = ...,
        ySplit: Incomplete | None = ...,
        topLeftCell: Incomplete | None = ...,
        activePane: str = ...,
        state: str = ...,
    ) -> None: ...

class Selection(Serialisable):  # type: ignore[misc]
    pane: Incomplete
    activeCell: Incomplete
    activeCellId: Incomplete
    sqref: Incomplete
    def __init__(
        self, pane: Incomplete | None = ..., activeCell: str = ..., activeCellId: Incomplete | None = ..., sqref: str = ...
    ) -> None: ...

class SheetView(Serialisable):
    tagname: str
    windowProtection: Incomplete
    showFormulas: Incomplete
    showGridLines: Incomplete
    showRowColHeaders: Incomplete
    showZeros: Incomplete
    rightToLeft: Incomplete
    tabSelected: Incomplete
    showRuler: Incomplete
    showOutlineSymbols: Incomplete
    defaultGridColor: Incomplete
    showWhiteSpace: Incomplete
    view: Incomplete
    topLeftCell: Incomplete
    colorId: Incomplete
    zoomScale: Incomplete
    zoomScaleNormal: Incomplete
    zoomScaleSheetLayoutView: Incomplete
    zoomScalePageLayoutView: Incomplete
    zoomToFit: Incomplete
    workbookViewId: Incomplete
    selection: Incomplete
    pane: Incomplete
    def __init__(
        self,
        windowProtection: Incomplete | None = ...,
        showFormulas: Incomplete | None = ...,
        showGridLines: Incomplete | None = ...,
        showRowColHeaders: Incomplete | None = ...,
        showZeros: Incomplete | None = ...,
        rightToLeft: Incomplete | None = ...,
        tabSelected: Incomplete | None = ...,
        showRuler: Incomplete | None = ...,
        showOutlineSymbols: Incomplete | None = ...,
        defaultGridColor: Incomplete | None = ...,
        showWhiteSpace: Incomplete | None = ...,
        view: Incomplete | None = ...,
        topLeftCell: Incomplete | None = ...,
        colorId: Incomplete | None = ...,
        zoomScale: Incomplete | None = ...,
        zoomScaleNormal: Incomplete | None = ...,
        zoomScaleSheetLayoutView: Incomplete | None = ...,
        zoomScalePageLayoutView: Incomplete | None = ...,
        zoomToFit: Incomplete | None = ...,
        workbookViewId: int = ...,
        selection: Incomplete | None = ...,
        pane: Incomplete | None = ...,
    ) -> None: ...

class SheetViewList(Serialisable):
    tagname: str
    sheetView: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(self, sheetView: Incomplete | None = ..., extLst: Incomplete | None = ...) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class Outline(Serialisable):
    tagname: str
    applyStyles: Incomplete
    summaryBelow: Incomplete
    summaryRight: Incomplete
    showOutlineSymbols: Incomplete
    def __init__(
        self,
        applyStyles: Incomplete | None = ...,
        summaryBelow: Incomplete | None = ...,
        summaryRight: Incomplete | None = ...,
        showOutlineSymbols: Incomplete | None = ...,
    ) -> None: ...

class PageSetupProperties(Serialisable):
    tagname: str
    autoPageBreaks: Incomplete
    fitToPage: Incomplete
    def __init__(self, autoPageBreaks: Incomplete | None = ..., fitToPage: Incomplete | None = ...) -> None: ...

class WorksheetProperties(Serialisable):
    tagname: str
    codeName: Incomplete
    enableFormatConditionsCalculation: Incomplete
    filterMode: Incomplete
    published: Incomplete
    syncHorizontal: Incomplete
    syncRef: Incomplete
    syncVertical: Incomplete
    transitionEvaluation: Incomplete
    transitionEntry: Incomplete
    tabColor: Incomplete
    outlinePr: Incomplete
    pageSetUpPr: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        codeName: Incomplete | None = ...,
        enableFormatConditionsCalculation: Incomplete | None = ...,
        filterMode: Incomplete | None = ...,
        published: Incomplete | None = ...,
        syncHorizontal: Incomplete | None = ...,
        syncRef: Incomplete | None = ...,
        syncVertical: Incomplete | None = ...,
        transitionEvaluation: Incomplete | None = ...,
        transitionEntry: Incomplete | None = ...,
        tabColor: Incomplete | None = ...,
        outlinePr: Incomplete | None = ...,
        pageSetUpPr: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class Point2D(Serialisable):
    tagname: str
    namespace: Incomplete
    x: Incomplete
    y: Incomplete
    def __init__(self, x: Incomplete | None = ..., y: Incomplete | None = ...) -> None: ...

class PositiveSize2D(Serialisable):
    tagname: str
    namespace: Incomplete
    cx: Incomplete
    width: Incomplete
    cy: Incomplete
    height: Incomplete
    def __init__(self, cx: Incomplete | None = ..., cy: Incomplete | None = ...) -> None: ...

class Transform2D(Serialisable):
    tagname: str
    namespace: Incomplete
    rot: Incomplete
    flipH: Incomplete
    flipV: Incomplete
    off: Incomplete
    ext: Incomplete
    chOff: Incomplete
    chExt: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        rot: Incomplete | None = ...,
        flipH: Incomplete | None = ...,
        flipV: Incomplete | None = ...,
        off: Incomplete | None = ...,
        ext: Incomplete | None = ...,
        chOff: Incomplete | None = ...,
        chExt: Incomplete | None = ...,
    ) -> None: ...

class GroupTransform2D(Serialisable):
    tagname: str
    namespace: Incomplete
    rot: Incomplete
    flipH: Incomplete
    flipV: Incomplete
    off: Incomplete
    ext: Incomplete
    chOff: Incomplete
    chExt: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        rot: int = ...,
        flipH: Incomplete | None = ...,
        flipV: Incomplete | None = ...,
        off: Incomplete | None = ...,
        ext: Incomplete | None = ...,
        chOff: Incomplete | None = ...,
        chExt: Incomplete | None = ...,
    ) -> None: ...

class SphereCoords(Serialisable):
    tagname: str
    lat: Incomplete
    lon: Incomplete
    rev: Incomplete
    def __init__(self, lat: Incomplete | None = ..., lon: Incomplete | None = ..., rev: Incomplete | None = ...) -> None: ...

class Camera(Serialisable):
    tagname: str
    prst: Incomplete
    fov: Incomplete
    zoom: Incomplete
    rot: Incomplete
    def __init__(
        self,
        prst: Incomplete | None = ...,
        fov: Incomplete | None = ...,
        zoom: Incomplete | None = ...,
        rot: Incomplete | None = ...,
    ) -> None: ...

class LightRig(Serialisable):
    tagname: str
    rig: Incomplete
    dir: Incomplete
    rot: Incomplete
    def __init__(self, rig: Incomplete | None = ..., dir: Incomplete | None = ..., rot: Incomplete | None = ...) -> None: ...

class Vector3D(Serialisable):
    tagname: str
    dx: Incomplete
    dy: Incomplete
    dz: Incomplete
    def __init__(self, dx: Incomplete | None = ..., dy: Incomplete | None = ..., dz: Incomplete | None = ...) -> None: ...

class Point3D(Serialisable):
    tagname: str
    x: Incomplete
    y: Incomplete
    z: Incomplete
    def __init__(self, x: Incomplete | None = ..., y: Incomplete | None = ..., z: Incomplete | None = ...) -> None: ...

class Backdrop(Serialisable):
    anchor: Incomplete
    norm: Incomplete
    up: Incomplete
    extLst: Incomplete
    def __init__(
        self,
        anchor: Incomplete | None = ...,
        norm: Incomplete | None = ...,
        up: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class Scene3D(Serialisable):
    camera: Incomplete
    lightRig: Incomplete
    backdrop: Incomplete
    extLst: Incomplete
    def __init__(
        self,
        camera: Incomplete | None = ...,
        lightRig: Incomplete | None = ...,
        backdrop: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class Bevel(Serialisable):
    tagname: str
    w: Incomplete
    h: Incomplete
    prst: Incomplete
    def __init__(self, w: Incomplete | None = ..., h: Incomplete | None = ..., prst: Incomplete | None = ...) -> None: ...

class Shape3D(Serialisable):
    namespace: Incomplete
    z: Incomplete
    extrusionH: Incomplete
    contourW: Incomplete
    prstMaterial: Incomplete
    bevelT: Incomplete
    bevelB: Incomplete
    extrusionClr: Incomplete
    contourClr: Incomplete
    extLst: Incomplete
    def __init__(
        self,
        z: Incomplete | None = ...,
        extrusionH: Incomplete | None = ...,
        contourW: Incomplete | None = ...,
        prstMaterial: Incomplete | None = ...,
        bevelT: Incomplete | None = ...,
        bevelB: Incomplete | None = ...,
        extrusionClr: Incomplete | None = ...,
        contourClr: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class Path2D(Serialisable):
    w: Incomplete
    h: Incomplete
    fill: Incomplete
    stroke: Incomplete
    extrusionOk: Incomplete
    def __init__(
        self,
        w: Incomplete | None = ...,
        h: Incomplete | None = ...,
        fill: Incomplete | None = ...,
        stroke: Incomplete | None = ...,
        extrusionOk: Incomplete | None = ...,
    ) -> None: ...

class Path2DList(Serialisable):
    path: Incomplete
    def __init__(self, path: Incomplete | None = ...) -> None: ...

class GeomRect(Serialisable):
    l: Incomplete
    t: Incomplete
    r: Incomplete
    b: Incomplete
    def __init__(
        self, l: Incomplete | None = ..., t: Incomplete | None = ..., r: Incomplete | None = ..., b: Incomplete | None = ...
    ) -> None: ...

class AdjPoint2D(Serialisable):
    x: Incomplete
    y: Incomplete
    def __init__(self, x: Incomplete | None = ..., y: Incomplete | None = ...) -> None: ...

class ConnectionSite(Serialisable):
    ang: Incomplete
    pos: Incomplete
    def __init__(self, ang: Incomplete | None = ..., pos: Incomplete | None = ...) -> None: ...

class ConnectionSiteList(Serialisable):
    cxn: Incomplete
    def __init__(self, cxn: Incomplete | None = ...) -> None: ...

class AdjustHandleList(Serialisable): ...

class GeomGuide(Serialisable):
    name: Incomplete
    fmla: Incomplete
    def __init__(self, name: Incomplete | None = ..., fmla: Incomplete | None = ...) -> None: ...

class GeomGuideList(Serialisable):
    gd: Incomplete
    def __init__(self, gd: Incomplete | None = ...) -> None: ...

class CustomGeometry2D(Serialisable):
    avLst: Incomplete
    gdLst: Incomplete
    ahLst: Incomplete
    cxnLst: Incomplete
    pathLst: Incomplete
    rect: Incomplete
    def __init__(
        self,
        avLst: Incomplete | None = ...,
        gdLst: Incomplete | None = ...,
        ahLst: Incomplete | None = ...,
        cxnLst: Incomplete | None = ...,
        rect: Incomplete | None = ...,
        pathLst: Incomplete | None = ...,
    ) -> None: ...

class PresetGeometry2D(Serialisable):
    namespace: Incomplete
    prst: Incomplete
    avLst: Incomplete
    def __init__(self, prst: Incomplete | None = ..., avLst: Incomplete | None = ...) -> None: ...

class FontReference(Serialisable):
    idx: Incomplete
    def __init__(self, idx: Incomplete | None = ...) -> None: ...

class StyleMatrixReference(Serialisable):
    idx: Incomplete
    def __init__(self, idx: Incomplete | None = ...) -> None: ...

class ShapeStyle(Serialisable):
    lnRef: Incomplete
    fillRef: Incomplete
    effectRef: Incomplete
    fontRef: Incomplete
    def __init__(
        self,
        lnRef: Incomplete | None = ...,
        fillRef: Incomplete | None = ...,
        effectRef: Incomplete | None = ...,
        fontRef: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class Connection(Serialisable):
    id: Incomplete
    idx: Incomplete
    def __init__(self, id: Incomplete | None = ..., idx: Incomplete | None = ...) -> None: ...

class ConnectorLocking(Serialisable):
    extLst: Incomplete
    def __init__(self, extLst: Incomplete | None = ...) -> None: ...

class NonVisualConnectorProperties(Serialisable):
    cxnSpLocks: Incomplete
    stCxn: Incomplete
    endCxn: Incomplete
    extLst: Incomplete
    def __init__(
        self,
        cxnSpLocks: Incomplete | None = ...,
        stCxn: Incomplete | None = ...,
        endCxn: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class ConnectorNonVisual(Serialisable):
    cNvPr: Incomplete
    cNvCxnSpPr: Incomplete
    __elements__: Incomplete
    def __init__(self, cNvPr: Incomplete | None = ..., cNvCxnSpPr: Incomplete | None = ...) -> None: ...

class ConnectorShape(Serialisable):
    tagname: str
    nvCxnSpPr: Incomplete
    spPr: Incomplete
    style: Incomplete
    macro: Incomplete
    fPublished: Incomplete
    def __init__(
        self,
        nvCxnSpPr: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        style: Incomplete | None = ...,
        macro: Incomplete | None = ...,
        fPublished: Incomplete | None = ...,
    ) -> None: ...

class ShapeMeta(Serialisable):
    tagname: str
    cNvPr: Incomplete
    cNvSpPr: Incomplete
    def __init__(self, cNvPr: Incomplete | None = ..., cNvSpPr: Incomplete | None = ...) -> None: ...

class Shape(Serialisable):
    macro: Incomplete
    textlink: Incomplete
    fPublished: Incomplete
    fLocksText: Incomplete
    nvSpPr: Incomplete
    meta: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    style: Incomplete
    txBody: Incomplete
    def __init__(
        self,
        macro: Incomplete | None = ...,
        textlink: Incomplete | None = ...,
        fPublished: Incomplete | None = ...,
        fLocksText: Incomplete | None = ...,
        nvSpPr: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        style: Incomplete | None = ...,
        txBody: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class ManualLayout(Serialisable):
    tagname: str
    layoutTarget: Incomplete
    xMode: Incomplete
    yMode: Incomplete
    wMode: Incomplete
    hMode: Incomplete
    x: Incomplete
    y: Incomplete
    w: Incomplete
    width: Incomplete
    h: Incomplete
    height: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        layoutTarget: Incomplete | None = ...,
        xMode: Incomplete | None = ...,
        yMode: Incomplete | None = ...,
        wMode: str = ...,
        hMode: str = ...,
        x: Incomplete | None = ...,
        y: Incomplete | None = ...,
        w: Incomplete | None = ...,
        h: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class Layout(Serialisable):
    tagname: str
    manualLayout: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(self, manualLayout: Incomplete | None = ..., extLst: Incomplete | None = ...) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class Break(Serialisable):
    tagname: str
    id: Incomplete
    min: Incomplete
    max: Incomplete
    man: Incomplete
    pt: Incomplete
    def __init__(self, id: int = ..., min: int = ..., max: int = ..., man: bool = ..., pt: Incomplete | None = ...) -> None: ...

class RowBreak(Serialisable):
    tagname: str
    # Overwritten by properties below
    # count: Integer
    # manualBreakCount: Integer
    brk: Incomplete
    __elements__: Incomplete
    __attrs__: Incomplete
    def __init__(self, count: Incomplete | None = ..., manualBreakCount: Incomplete | None = ..., brk=...) -> None: ...
    def __bool__(self) -> bool: ...
    def __len__(self) -> int: ...
    @property
    def count(self): ...
    @property
    def manualBreakCount(self): ...
    def append(self, brk: Incomplete | None = ...) -> None: ...

PageBreak = RowBreak

class ColBreak(RowBreak):
    tagname: str
    @property
    def count(self): ...
    @property
    def manualBreakCount(self): ...
    brk: Incomplete
    __attrs__: Incomplete



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class WebPublishObject(Serialisable):
    tagname: str
    id: Incomplete
    divId: Incomplete
    sourceObject: Incomplete
    destinationFile: Incomplete
    title: Incomplete
    autoRepublish: Incomplete
    def __init__(
        self,
        id: Incomplete | None = ...,
        divId: Incomplete | None = ...,
        sourceObject: Incomplete | None = ...,
        destinationFile: Incomplete | None = ...,
        title: Incomplete | None = ...,
        autoRepublish: Incomplete | None = ...,
    ) -> None: ...

class WebPublishObjectList(Serialisable):
    tagname: str
    # Overwritten by property below
    # count: Integer
    webPublishObject: Incomplete
    __elements__: Incomplete
    def __init__(self, count: Incomplete | None = ..., webPublishObject=...) -> None: ...
    @property
    def count(self): ...

class WebPublishing(Serialisable):
    tagname: str
    css: Incomplete
    thicket: Incomplete
    longFileNames: Incomplete
    vml: Incomplete
    allowPng: Incomplete
    targetScreenSize: Incomplete
    dpi: Incomplete
    codePage: Incomplete
    characterSet: Incomplete
    def __init__(
        self,
        css: Incomplete | None = ...,
        thicket: Incomplete | None = ...,
        longFileNames: Incomplete | None = ...,
        vml: Incomplete | None = ...,
        allowPng: Incomplete | None = ...,
        targetScreenSize: str = ...,
        dpi: Incomplete | None = ...,
        codePage: Incomplete | None = ...,
        characterSet: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class Index(Serialisable):
    tagname: str
    v: Incomplete
    def __init__(self, v: int = ...) -> None: ...

class Tuple(Serialisable):  # type: ignore[misc]
    fld: Incomplete
    hier: Incomplete
    item: Incomplete
    def __init__(self, fld: Incomplete | None = ..., hier: Incomplete | None = ..., item: Incomplete | None = ...) -> None: ...

class TupleList(Serialisable):  # type: ignore[misc]
    c: Incomplete
    tpl: Incomplete
    __elements__: Incomplete
    def __init__(self, c: Incomplete | None = ..., tpl: Incomplete | None = ...) -> None: ...

class Missing(Serialisable):
    tagname: str
    tpls: Incomplete
    x: Incomplete
    u: Incomplete
    f: Incomplete
    c: Incomplete
    cp: Incomplete
    bc: Incomplete
    fc: Incomplete
    i: Incomplete
    un: Incomplete
    st: Incomplete
    b: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        tpls=...,
        x=...,
        u: Incomplete | None = ...,
        f: Incomplete | None = ...,
        c: Incomplete | None = ...,
        cp: Incomplete | None = ...,
        _in: Incomplete | None = ...,
        bc: Incomplete | None = ...,
        fc: Incomplete | None = ...,
        i: Incomplete | None = ...,
        un: Incomplete | None = ...,
        st: Incomplete | None = ...,
        b: Incomplete | None = ...,
    ) -> None: ...

class Number(Serialisable):
    tagname: str
    tpls: Incomplete
    x: Incomplete
    v: Incomplete
    u: Incomplete
    f: Incomplete
    c: Incomplete
    cp: Incomplete
    bc: Incomplete
    fc: Incomplete
    i: Incomplete
    un: Incomplete
    st: Incomplete
    b: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        tpls=...,
        x=...,
        v: Incomplete | None = ...,
        u: Incomplete | None = ...,
        f: Incomplete | None = ...,
        c: Incomplete | None = ...,
        cp: Incomplete | None = ...,
        _in: Incomplete | None = ...,
        bc: Incomplete | None = ...,
        fc: Incomplete | None = ...,
        i: Incomplete | None = ...,
        un: Incomplete | None = ...,
        st: Incomplete | None = ...,
        b: Incomplete | None = ...,
    ) -> None: ...

class Error(Serialisable):
    tagname: str
    tpls: Incomplete
    x: Incomplete
    v: Incomplete
    u: Incomplete
    f: Incomplete
    c: Incomplete
    cp: Incomplete
    bc: Incomplete
    fc: Incomplete
    i: Incomplete
    un: Incomplete
    st: Incomplete
    b: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        tpls: Incomplete | None = ...,
        x=...,
        v: Incomplete | None = ...,
        u: Incomplete | None = ...,
        f: Incomplete | None = ...,
        c: Incomplete | None = ...,
        cp: Incomplete | None = ...,
        _in: Incomplete | None = ...,
        bc: Incomplete | None = ...,
        fc: Incomplete | None = ...,
        i: Incomplete | None = ...,
        un: Incomplete | None = ...,
        st: Incomplete | None = ...,
        b: Incomplete | None = ...,
    ) -> None: ...

class Boolean(Serialisable):
    tagname: str
    x: Incomplete
    v: Incomplete
    u: Incomplete
    f: Incomplete
    c: Incomplete
    cp: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        x=...,
        v: Incomplete | None = ...,
        u: Incomplete | None = ...,
        f: Incomplete | None = ...,
        c: Incomplete | None = ...,
        cp: Incomplete | None = ...,
    ) -> None: ...

class Text(Serialisable):
    tagname: str
    tpls: Incomplete
    x: Incomplete
    v: Incomplete
    u: Incomplete
    f: Incomplete
    c: Incomplete
    cp: Incomplete
    bc: Incomplete
    fc: Incomplete
    i: Incomplete
    un: Incomplete
    st: Incomplete
    b: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        tpls=...,
        x=...,
        v: Incomplete | None = ...,
        u: Incomplete | None = ...,
        f: Incomplete | None = ...,
        c: Incomplete | None = ...,
        cp: Incomplete | None = ...,
        _in: Incomplete | None = ...,
        bc: Incomplete | None = ...,
        fc: Incomplete | None = ...,
        i: Incomplete | None = ...,
        un: Incomplete | None = ...,
        st: Incomplete | None = ...,
        b: Incomplete | None = ...,
    ) -> None: ...

class DateTimeField(Serialisable):
    tagname: str
    x: Incomplete
    v: Incomplete
    u: Incomplete
    f: Incomplete
    c: Incomplete
    cp: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        x=...,
        v: Incomplete | None = ...,
        u: Incomplete | None = ...,
        f: Incomplete | None = ...,
        c: Incomplete | None = ...,
        cp: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

attribute_mapping: Incomplete

class SeriesLabel(Serialisable):
    tagname: str
    strRef: Incomplete
    v: Incomplete
    value: Incomplete
    __elements__: Incomplete
    def __init__(self, strRef: Incomplete | None = ..., v: Incomplete | None = ...) -> None: ...

class Series(Serialisable):
    tagname: str
    idx: Incomplete
    order: Incomplete
    tx: Incomplete
    title: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    pictureOptions: Incomplete
    dPt: Incomplete
    data_points: Incomplete
    dLbls: Incomplete
    labels: Incomplete
    trendline: Incomplete
    errBars: Incomplete
    cat: Incomplete
    identifiers: Incomplete
    val: Incomplete
    extLst: Incomplete
    invertIfNegative: Incomplete
    shape: Incomplete
    xVal: Incomplete
    yVal: Incomplete
    bubbleSize: Incomplete
    zVal: Incomplete
    bubble3D: Incomplete
    marker: Incomplete
    smooth: Incomplete
    explosion: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        idx: int = ...,
        order: int = ...,
        tx: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        pictureOptions: Incomplete | None = ...,
        dPt=...,
        dLbls: Incomplete | None = ...,
        trendline: Incomplete | None = ...,
        errBars: Incomplete | None = ...,
        cat: Incomplete | None = ...,
        val: Incomplete | None = ...,
        invertIfNegative: Incomplete | None = ...,
        shape: Incomplete | None = ...,
        xVal: Incomplete | None = ...,
        yVal: Incomplete | None = ...,
        bubbleSize: Incomplete | None = ...,
        bubble3D: Incomplete | None = ...,
        marker: Incomplete | None = ...,
        smooth: Incomplete | None = ...,
        explosion: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...
    def to_tree(self, tagname: Incomplete | None = ..., idx: Incomplete | None = ...): ...  # type: ignore[override]

class XYSeries(Series):
    idx: Incomplete
    order: Incomplete
    tx: Incomplete
    spPr: Incomplete
    dPt: Incomplete
    dLbls: Incomplete
    trendline: Incomplete
    errBars: Incomplete
    xVal: Incomplete
    yVal: Incomplete
    invertIfNegative: Incomplete
    bubbleSize: Incomplete
    bubble3D: Incomplete
    marker: Incomplete
    smooth: Incomplete



from _typeshed import Incomplete

class WorksheetCopy:
    source: Incomplete
    target: Incomplete
    def __init__(self, source_worksheet, target_worksheet) -> None: ...
    def copy_worksheet(self) -> None: ...



from _typeshed import Incomplete
from collections.abc import Generator

from .base import Alias, Descriptor

class Sequence(Descriptor):
    expected_type: Incomplete
    seq_types: Incomplete
    idx_base: int
    unique: bool
    def __set__(self, instance, seq) -> None: ...
    def to_tree(self, tagname, obj, namespace: Incomplete | None = ...) -> Generator[Incomplete, None, None]: ...

class ValueSequence(Sequence):
    attribute: str
    def to_tree(self, tagname, obj, namespace: Incomplete | None = ...) -> Generator[Incomplete, None, None]: ...
    def from_tree(self, node): ...

class NestedSequence(Sequence):
    count: bool
    def to_tree(self, tagname, obj, namespace: Incomplete | None = ...): ...
    def from_tree(self, node): ...

class MultiSequence(Sequence):
    def __set__(self, instance, seq) -> None: ...
    def to_tree(self, tagname, obj, namespace: Incomplete | None = ...) -> Generator[Incomplete, None, None]: ...

class MultiSequencePart(Alias):
    expected_type: Incomplete
    store: Incomplete
    def __init__(self, expected_type, store) -> None: ...
    def __set__(self, instance, value) -> None: ...
    def __get__(self, instance, cls): ...



from _typeshed import Incomplete

from openpyxl.styles.styleable import StyleableObject

__docformat__: str
TIME_TYPES: Incomplete
TIME_FORMATS: Incomplete
STRING_TYPES: Incomplete
KNOWN_TYPES: Incomplete
ILLEGAL_CHARACTERS_RE: Incomplete
ERROR_CODES: Incomplete
TYPE_STRING: str
TYPE_FORMULA: str
TYPE_NUMERIC: str
TYPE_BOOL: str
TYPE_NULL: str
TYPE_INLINE: str
TYPE_ERROR: str
TYPE_FORMULA_CACHE_STRING: str
VALID_TYPES: Incomplete

def get_type(t, value): ...
def get_time_format(t): ...

class Cell(StyleableObject):
    row: Incomplete
    column: Incomplete
    data_type: str
    def __init__(
        self,
        worksheet,
        row: Incomplete | None = ...,
        column: Incomplete | None = ...,
        value: Incomplete | None = ...,
        style_array: Incomplete | None = ...,
    ) -> None: ...
    @property
    def coordinate(self): ...
    @property
    def col_idx(self): ...
    @property
    def column_letter(self): ...
    @property
    def encoding(self): ...
    @property
    def base_date(self): ...
    def check_string(self, value): ...
    def check_error(self, value): ...
    @property
    def value(self): ...
    @value.setter
    def value(self, value) -> None: ...
    @property
    def internal_value(self): ...
    @property
    def hyperlink(self): ...
    @hyperlink.setter
    def hyperlink(self, val) -> None: ...
    @property
    def is_date(self): ...
    def offset(self, row: int = ..., column: int = ...): ...
    @property
    def comment(self): ...
    @comment.setter
    def comment(self, value) -> None: ...

class MergedCell(StyleableObject):
    data_type: str
    comment: Incomplete
    hyperlink: Incomplete
    row: Incomplete
    column: Incomplete
    def __init__(self, worksheet, row: Incomplete | None = ..., column: Incomplete | None = ...) -> None: ...
    @property
    def coordinate(self): ...
    value: Incomplete

def WriteOnlyCell(ws: Incomplete | None = ..., value: Incomplete | None = ...): ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class WorkbookProtection(Serialisable):
    tagname: str
    workbook_password: Incomplete
    workbookPasswordCharacterSet: Incomplete
    revision_password: Incomplete
    revisionsPasswordCharacterSet: Incomplete
    lockStructure: Incomplete
    lock_structure: Incomplete
    lockWindows: Incomplete
    lock_windows: Incomplete
    lockRevision: Incomplete
    lock_revision: Incomplete
    revisionsAlgorithmName: Incomplete
    revisionsHashValue: Incomplete
    revisionsSaltValue: Incomplete
    revisionsSpinCount: Incomplete
    workbookAlgorithmName: Incomplete
    workbookHashValue: Incomplete
    workbookSaltValue: Incomplete
    workbookSpinCount: Incomplete
    __attrs__: Incomplete
    def __init__(
        self,
        workbookPassword: Incomplete | None = ...,
        workbookPasswordCharacterSet: Incomplete | None = ...,
        revisionsPassword: Incomplete | None = ...,
        revisionsPasswordCharacterSet: Incomplete | None = ...,
        lockStructure: Incomplete | None = ...,
        lockWindows: Incomplete | None = ...,
        lockRevision: Incomplete | None = ...,
        revisionsAlgorithmName: Incomplete | None = ...,
        revisionsHashValue: Incomplete | None = ...,
        revisionsSaltValue: Incomplete | None = ...,
        revisionsSpinCount: Incomplete | None = ...,
        workbookAlgorithmName: Incomplete | None = ...,
        workbookHashValue: Incomplete | None = ...,
        workbookSaltValue: Incomplete | None = ...,
        workbookSpinCount: Incomplete | None = ...,
    ) -> None: ...
    def set_workbook_password(self, value: str = ..., already_hashed: bool = ...) -> None: ...
    @property
    def workbookPassword(self): ...
    @workbookPassword.setter
    def workbookPassword(self, value) -> None: ...
    def set_revisions_password(self, value: str = ..., already_hashed: bool = ...) -> None: ...
    @property
    def revisionsPassword(self): ...
    @revisionsPassword.setter
    def revisionsPassword(self, value) -> None: ...
    @classmethod
    def from_tree(cls, node): ...

DocumentSecurity = WorkbookProtection

class FileSharing(Serialisable):
    tagname: str
    readOnlyRecommended: Incomplete
    userName: Incomplete
    reservationPassword: Incomplete
    algorithmName: Incomplete
    hashValue: Incomplete
    saltValue: Incomplete
    spinCount: Incomplete
    def __init__(
        self,
        readOnlyRecommended: Incomplete | None = ...,
        userName: Incomplete | None = ...,
        reservationPassword: Incomplete | None = ...,
        algorithmName: Incomplete | None = ...,
        hashValue: Incomplete | None = ...,
        saltValue: Incomplete | None = ...,
        spinCount: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable as Serialisable

class ChartsheetProperties(Serialisable):
    tagname: str
    published: Incomplete
    codeName: Incomplete
    tabColor: Incomplete
    __elements__: Incomplete
    def __init__(
        self, published: Incomplete | None = ..., codeName: Incomplete | None = ..., tabColor: Incomplete | None = ...
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class ObjectAnchor(Serialisable):
    tagname: str
    to: Incomplete
    moveWithCells: Incomplete
    sizeWithCells: Incomplete
    z_order: Incomplete
    def __init__(
        self,
        _from: Incomplete | None = ...,
        to: Incomplete | None = ...,
        moveWithCells: bool = ...,
        sizeWithCells: bool = ...,
        z_order: Incomplete | None = ...,
    ) -> None: ...

class ObjectPr(Serialisable):
    tagname: str
    anchor: Incomplete
    locked: Incomplete
    defaultSize: Incomplete
    disabled: Incomplete
    uiObject: Incomplete
    autoFill: Incomplete
    autoLine: Incomplete
    autoPict: Incomplete
    macro: Incomplete
    altText: Incomplete
    dde: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        anchor: Incomplete | None = ...,
        locked: bool = ...,
        defaultSize: bool = ...,
        _print: bool = ...,
        disabled: bool = ...,
        uiObject: bool = ...,
        autoFill: bool = ...,
        autoLine: bool = ...,
        autoPict: bool = ...,
        macro: Incomplete | None = ...,
        altText: Incomplete | None = ...,
        dde: bool = ...,
    ) -> None: ...

class OleObject(Serialisable):
    tagname: str
    objectPr: Incomplete
    progId: Incomplete
    dvAspect: Incomplete
    link: Incomplete
    oleUpdate: Incomplete
    autoLoad: Incomplete
    shapeId: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        objectPr: Incomplete | None = ...,
        progId: Incomplete | None = ...,
        dvAspect: str = ...,
        link: Incomplete | None = ...,
        oleUpdate: Incomplete | None = ...,
        autoLoad: bool = ...,
        shapeId: Incomplete | None = ...,
    ) -> None: ...

class OleObjects(Serialisable):
    tagname: str
    oleObject: Incomplete
    __elements__: Incomplete
    def __init__(self, oleObject=...) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors import Typed
from openpyxl.descriptors.serialisable import Serialisable

COLOR_INDEX: Incomplete
BLACK: Incomplete
WHITE: Incomplete
BLUE: Incomplete
aRGB_REGEX: Incomplete

class RGB(Typed):
    expected_type: Incomplete
    def __set__(self, instance, value) -> None: ...

class Color(Serialisable):
    tagname: str
    rgb: Incomplete
    indexed: Incomplete
    auto: Incomplete
    theme: Incomplete
    tint: Incomplete
    type: Incomplete
    def __init__(
        self,
        rgb=...,
        indexed: Incomplete | None = ...,
        auto: Incomplete | None = ...,
        theme: Incomplete | None = ...,
        tint: float = ...,
        index: Incomplete | None = ...,
        type: str = ...,
    ) -> None: ...
    @property
    def value(self): ...
    @value.setter
    def value(self, value) -> None: ...
    def __iter__(self): ...
    @property
    def index(self): ...
    def __add__(self, other): ...

class ColorDescriptor(Typed):
    expected_type: Incomplete
    def __set__(self, instance, value) -> None: ...

class RgbColor(Serialisable):
    tagname: str
    rgb: Incomplete
    def __init__(self, rgb: Incomplete | None = ...) -> None: ...

class ColorList(Serialisable):
    tagname: str
    indexedColors: Incomplete
    mruColors: Incomplete
    __elements__: Incomplete
    def __init__(self, indexedColors=..., mruColors=...) -> None: ...
    def __bool__(self) -> bool: ...
    @property
    def index(self): ...



from _typeshed import Incomplete
from warnings import warn as warn

class StyleDescriptor:
    collection: Incomplete
    key: Incomplete
    def __init__(self, collection, key) -> None: ...
    def __set__(self, instance, value) -> None: ...
    def __get__(self, instance, cls): ...

class NumberFormatDescriptor:
    key: str
    collection: str
    def __set__(self, instance, value) -> None: ...
    def __get__(self, instance, cls): ...

class NamedStyleDescriptor:
    key: str
    collection: str
    def __set__(self, instance, value) -> None: ...
    def __get__(self, instance, cls): ...

class StyleArrayDescriptor:
    key: Incomplete
    def __init__(self, key) -> None: ...
    def __set__(self, instance, value) -> None: ...
    def __get__(self, instance, cls): ...

class StyleableObject:
    font: Incomplete
    fill: Incomplete
    border: Incomplete
    number_format: Incomplete
    protection: Incomplete
    alignment: Incomplete
    style: Incomplete
    quotePrefix: Incomplete
    pivotButton: Incomplete
    parent: Incomplete
    def __init__(self, sheet, style_array: Incomplete | None = ...) -> None: ...
    @property
    def style_id(self): ...
    @property
    def has_style(self): ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class DifferentialStyle(Serialisable):
    tagname: str
    __elements__: Incomplete
    font: Incomplete
    numFmt: Incomplete
    fill: Incomplete
    alignment: Incomplete
    border: Incomplete
    protection: Incomplete
    extLst: Incomplete
    def __init__(
        self,
        font: Incomplete | None = ...,
        numFmt: Incomplete | None = ...,
        fill: Incomplete | None = ...,
        alignment: Incomplete | None = ...,
        border: Incomplete | None = ...,
        protection: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class DifferentialStyleList(Serialisable):
    tagname: str
    dxf: Incomplete
    styles: Incomplete
    __attrs__: Incomplete
    def __init__(self, dxf=..., count: Incomplete | None = ...) -> None: ...
    def append(self, dxf) -> None: ...
    def add(self, dxf): ...
    def __bool__(self) -> bool: ...
    def __getitem__(self, idx): ...
    @property
    def count(self): ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class TrendlineLabel(Serialisable):
    tagname: str
    layout: Incomplete
    tx: Incomplete
    numFmt: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    txPr: Incomplete
    textProperties: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        layout: Incomplete | None = ...,
        tx: Incomplete | None = ...,
        numFmt: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        txPr: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...

class Trendline(Serialisable):
    tagname: str
    name: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    trendlineType: Incomplete
    order: Incomplete
    period: Incomplete
    forward: Incomplete
    backward: Incomplete
    intercept: Incomplete
    dispRSqr: Incomplete
    dispEq: Incomplete
    trendlineLbl: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        name: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        trendlineType: str = ...,
        order: Incomplete | None = ...,
        period: Incomplete | None = ...,
        forward: Incomplete | None = ...,
        backward: Incomplete | None = ...,
        intercept: Incomplete | None = ...,
        dispRSqr: Incomplete | None = ...,
        dispEq: Incomplete | None = ...,
        trendlineLbl: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

def collapse_cell_addresses(cells, input_ranges=...): ...
def expand_cell_ranges(range_string): ...

class DataValidation(Serialisable):
    tagname: str
    sqref: Incomplete
    cells: Incomplete
    ranges: Incomplete
    showErrorMessage: Incomplete
    showDropDown: Incomplete
    hide_drop_down: Incomplete
    showInputMessage: Incomplete
    allowBlank: Incomplete
    allow_blank: Incomplete
    errorTitle: Incomplete
    error: Incomplete
    promptTitle: Incomplete
    prompt: Incomplete
    formula1: Incomplete
    formula2: Incomplete
    type: Incomplete
    errorStyle: Incomplete
    imeMode: Incomplete
    operator: Incomplete
    validation_type: Incomplete
    def __init__(
        self,
        type: Incomplete | None = ...,
        formula1: Incomplete | None = ...,
        formula2: Incomplete | None = ...,
        showErrorMessage: bool = ...,
        showInputMessage: bool = ...,
        showDropDown: Incomplete | None = ...,
        allowBlank: Incomplete | None = ...,
        sqref=...,
        promptTitle: Incomplete | None = ...,
        errorStyle: Incomplete | None = ...,
        error: Incomplete | None = ...,
        prompt: Incomplete | None = ...,
        errorTitle: Incomplete | None = ...,
        imeMode: Incomplete | None = ...,
        operator: Incomplete | None = ...,
        allow_blank: Incomplete | None = ...,
    ) -> None: ...
    def add(self, cell) -> None: ...
    def __contains__(self, cell): ...

class DataValidationList(Serialisable):
    tagname: str
    disablePrompts: Incomplete
    xWindow: Incomplete
    yWindow: Incomplete
    dataValidation: Incomplete
    __elements__: Incomplete
    __attrs__: Incomplete
    def __init__(
        self,
        disablePrompts: Incomplete | None = ...,
        xWindow: Incomplete | None = ...,
        yWindow: Incomplete | None = ...,
        count: Incomplete | None = ...,
        dataValidation=...,
    ) -> None: ...
    @property
    def count(self): ...
    def __len__(self) -> int: ...
    def append(self, dv) -> None: ...
    def to_tree(self, tagname: Incomplete | None = ...): ...  # type: ignore[override]



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class FileRecoveryProperties(Serialisable):
    tagname: str
    autoRecover: Incomplete
    crashSave: Incomplete
    dataExtractLoad: Incomplete
    repairLoad: Incomplete
    def __init__(
        self,
        autoRecover: Incomplete | None = ...,
        crashSave: Incomplete | None = ...,
        dataExtractLoad: Incomplete | None = ...,
        repairLoad: Incomplete | None = ...,
    ) -> None: ...

class ChildSheet(Serialisable):
    tagname: str
    name: Incomplete
    sheetId: Incomplete
    state: Incomplete
    id: Incomplete
    def __init__(
        self, name: Incomplete | None = ..., sheetId: Incomplete | None = ..., state: str = ..., id: Incomplete | None = ...
    ) -> None: ...

class PivotCache(Serialisable):
    tagname: str
    cacheId: Incomplete
    id: Incomplete
    def __init__(self, cacheId: Incomplete | None = ..., id: Incomplete | None = ...) -> None: ...

class WorkbookPackage(Serialisable):
    tagname: str
    conformance: Incomplete
    fileVersion: Incomplete
    fileSharing: Incomplete
    workbookPr: Incomplete
    properties: Incomplete
    workbookProtection: Incomplete
    bookViews: Incomplete
    sheets: Incomplete
    functionGroups: Incomplete
    externalReferences: Incomplete
    definedNames: Incomplete
    calcPr: Incomplete
    oleSize: Incomplete
    customWorkbookViews: Incomplete
    pivotCaches: Incomplete
    smartTagPr: Incomplete
    smartTagTypes: Incomplete
    webPublishing: Incomplete
    fileRecoveryPr: Incomplete
    webPublishObjects: Incomplete
    extLst: Incomplete
    Ignorable: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        conformance: Incomplete | None = ...,
        fileVersion: Incomplete | None = ...,
        fileSharing: Incomplete | None = ...,
        workbookPr: Incomplete | None = ...,
        workbookProtection: Incomplete | None = ...,
        bookViews=...,
        sheets=...,
        functionGroups: Incomplete | None = ...,
        externalReferences=...,
        definedNames: Incomplete | None = ...,
        calcPr: Incomplete | None = ...,
        oleSize: Incomplete | None = ...,
        customWorkbookViews=...,
        pivotCaches=...,
        smartTagPr: Incomplete | None = ...,
        smartTagTypes: Incomplete | None = ...,
        webPublishing: Incomplete | None = ...,
        fileRecoveryPr: Incomplete | None = ...,
        webPublishObjects: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
        Ignorable: Incomplete | None = ...,
    ) -> None: ...
    def to_tree(self): ...
    @property
    def active(self): ...
    @property
    def pivot_caches(self): ...



from _typeshed import Incomplete
from abc import abstractmethod

from openpyxl.descriptors.serialisable import Serialisable as Serialisable

class _DataLabelBase(Serialisable):
    numFmt: Incomplete
    spPr: Incomplete
    graphicalProperties: Incomplete
    txPr: Incomplete
    textProperties: Incomplete
    dLblPos: Incomplete
    position: Incomplete
    showLegendKey: Incomplete
    showVal: Incomplete
    showCatName: Incomplete
    showSerName: Incomplete
    showPercent: Incomplete
    showBubbleSize: Incomplete
    showLeaderLines: Incomplete
    separator: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        numFmt: Incomplete | None = ...,
        spPr: Incomplete | None = ...,
        txPr: Incomplete | None = ...,
        dLblPos: Incomplete | None = ...,
        showLegendKey: Incomplete | None = ...,
        showVal: Incomplete | None = ...,
        showCatName: Incomplete | None = ...,
        showSerName: Incomplete | None = ...,
        showPercent: Incomplete | None = ...,
        showBubbleSize: Incomplete | None = ...,
        showLeaderLines: Incomplete | None = ...,
        separator: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...
    @property
    @abstractmethod
    def tagname(self) -> str: ...

class DataLabel(_DataLabelBase):
    tagname: str
    idx: Incomplete
    numFmt: Incomplete
    spPr: Incomplete
    txPr: Incomplete
    dLblPos: Incomplete
    showLegendKey: Incomplete
    showVal: Incomplete
    showCatName: Incomplete
    showSerName: Incomplete
    showPercent: Incomplete
    showBubbleSize: Incomplete
    showLeaderLines: Incomplete
    separator: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(self, idx: int = ..., **kw) -> None: ...

class DataLabelList(_DataLabelBase):
    tagname: str
    dLbl: Incomplete
    delete: Incomplete
    numFmt: Incomplete
    spPr: Incomplete
    txPr: Incomplete
    dLblPos: Incomplete
    showLegendKey: Incomplete
    showVal: Incomplete
    showCatName: Incomplete
    showSerName: Incomplete
    showPercent: Incomplete
    showBubbleSize: Incomplete
    showLeaderLines: Incomplete
    separator: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(self, dLbl=..., delete: Incomplete | None = ..., **kw) -> None: ...



from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class AuthorList(Serialisable):
    tagname: str
    author: Incomplete
    authors: Incomplete
    def __init__(self, author=...) -> None: ...



from _typeshed import Incomplete
from collections.abc import Generator

from openpyxl.descriptors.serialisable import Serialisable

class Relationship(Serialisable):
    tagname: str
    Type: Incomplete
    Target: Incomplete
    target: Incomplete
    TargetMode: Incomplete
    Id: Incomplete
    id: Incomplete
    def __init__(
        self,
        Id: Incomplete | None = ...,
        Type: Incomplete | None = ...,
        type: Incomplete | None = ...,
        Target: Incomplete | None = ...,
        TargetMode: Incomplete | None = ...,
    ) -> None: ...

class RelationshipList(Serialisable):
    tagname: str
    Relationship: Incomplete
    def __init__(self, Relationship=...) -> None: ...
    def append(self, value) -> None: ...
    def __len__(self) -> int: ...
    def __bool__(self) -> bool: ...
    def find(self, content_type) -> Generator[Incomplete, None, None]: ...
    def __getitem__(self, key): ...
    def to_tree(self): ...

def get_rels_path(path): ...
def get_dependents(archive, filename): ...
def get_rel(archive, deps, id: Incomplete | None = ..., cls: Incomplete | None = ...): ...
